function AbstractDataListUI() {
	this._header = null;
	this._contentId = null;
	this._listViewId = null;
	this._entryId = null;
	this._entryTemplateId = null;
	this._sortBy = null;	
	this._detailViewId = null;
	this._menuItemId = null;
	this._dirty = false;
	this._showDetailOnSelect = true;
	
	this._cssListColSize = 'col-md-12';
	this._cssListWithDetailColSize = 'col-sm-6 col-md-6 col-lg-7';
	this._cssDetailColSize = 'col-sm-6 col-md-6 col-lg-5';
	
	this._listEntryHandler = null;
	this._getEntryHandler = null;
	this._newEntryHandler = null;
	this._updateEntryHandler = null;
	this._addEntryHandler = null;
	this._beforeRemoveEntryHandler = null;
	this._removeEntryHandler = null;
	this._validateEntryHandler = null;
	this._lockEntryHandler = null;
	this._unlockEntryHandler = null;
	this._cloneEntryHandler = null;
};

AbstractDataListUI.prototype.initUI = function() {
	var self = this;
	
	if (this._listViewId) {
		$(this._listViewId).find('.tools').click(function() {
			$(this).closest(self._listViewId).find(self._entryId).removeClass('active');
			$(this).addClass('active');
		});
	}		
	if (this._contentId) {
		$(this._contentId).find('.list-filter input[name="filter"]').on(
			'input change propertychange paste keyup',
			function() {
				var filterText = $(this).val();
				self.onFilterChanged(filterText);
			}
		);
	}
	
	if (this._detailViewId) {
		if (this._validateEntryHandler) {
			$(this._detailViewId).find('input,select,textarea').blur(function() {
				var model = {};
				try {
					self.toModel($(self._detailViewId), model);
				} catch (e) {
					console.log(e);
				}
				self.validate(model);
			});			
		}
		
		$(this._detailViewId).find('input,select,textarea').change(function() {
			self._dirty = true;
		});		
	}
};

AbstractDataListUI.prototype.adjustContent = function() {
	var windowHeight = $(window).height();
	var navbarHeight = $('.navbar-fixed-top').outerHeight(true);
	var maxHeight = windowHeight > navbarHeight ? windowHeight : navbarHeight;
	
	var detailHeight = maxHeight - $('.navbar.navbar-default').outerHeight(true) - ($('.list-filter').is(":visible") ? $('.list-filter').outerHeight(true): 0);
	$('.detail').css('min-height', detailHeight);
	$('.detail-content').css('min-height', detailHeight - 100);
	
	$('.scrollable-data-list').css('min-height', detailHeight);
	$('.scrollable-data-list').css('height', detailHeight);
};

AbstractDataListUI.prototype.showUI = function(source, detailId) {
	var self = this;
	
	this.hideDetailUI();
	this.clearFilter(); 
	if (typeof(this._listEntryHandler) == 'function') {
		this._listEntryHandler(
				function(data, textStatus, jqXHR) {
					self.onEntriesSuccess(data, textStatus, jqXHR);	
					if (detailId) {
						self.selectEntry($(self._entryId + '[id="' + detailId + '"]'));
					}
				}, 
				EHexServiceUtil.onErrorHandler, 
				this
			);
	}	
};

AbstractDataListUI.prototype.showDetailUI = function(source, e, model) {
	var self = this;
	
	if (!this._detailViewId) {
		return;
	}
	
	this.confirmDirty(function(result) {
		if (result) {
			var viewElement =  $(self._detailViewId);
			viewElement.prev().removeClass(self._cssListColSize).addClass(self._cssListWithDetailColSize);
			viewElement.addClass(self._cssDetailColSize).css('display', 'block');
			
			var id = $(source).closest(self._entryId).attr('id');
			if (id != null && id != '') {
				if (model != null) {
					self.toDetailView(model, viewElement);
				} else if (typeof(self._getEntryHandler) === 'function') {
					self._getEntryHandler(id, self.onEntrySuccess, EHexServiceUtil.onErrorHandler, self);
				} else {
					var emptyModel = {};	
					self.toDetailView(emptyModel, viewElement);
				}
				self._dirty = false;
			} else {
				$(self._listViewId).find(self._entryId).removeClass('active');
				$(self._listViewId).find('.new-record').addClass('active');
				$(self._listViewId).scrollTop(0);
				$(self._listViewId).find('.new-record').show();
				if (model != null) {
					self.toDetailView(model, viewElement);
				} else if (typeof(self._newEntryHandler) === 'function') {
					self._newEntryHandler(self.onEntrySuccess, EHexServiceUtil.onErrorHandler, self);
				} else {
					var emptyModel = {};	
					self.toDetailView(emptyModel, viewElement);
				}
				self._dirty = true;
			}
			
			var detailHeight = $(window).height() - $('.navbar.navbar-default').outerHeight(true) - $('.list-filter').outerHeight(true);
			$(self._detailViewId).css('min-height', detailHeight);
		}
	});
};

AbstractDataListUI.prototype.hideDetailUI = function() {
	var self = this;
	
	$(this._detailViewId).prev().children().removeClass('active');
	$(this._detailViewId).prev()
		.removeClass('active')
		.removeClass(self._cssListWithDetailColSize)
		.addClass(self._cssListColSize);
	$(this._detailViewId)
		.css('display', 'none')
		.removeClass(self._cssDetailColSize);
	
	$(this._listViewId).find('.new-record').hide();
	this._dirty = false;
};

AbstractDataListUI.prototype.applyDetailUI = function() {
	try {
		var self = this;
		
		if (!this._detailViewId) {
			return;
		}
		
		var viewElement = $(self._detailViewId);
		var model = {};
		
		var validationResult = self.toModel(viewElement, model);
		
		this.confirmWarnings(validationResult, function(result) {
			if (result) {
				if (model.id == null || model.id == '') {
					self._addEntryHandler(model, self.onApplyDetailUISuccess, EHexServiceUtil.onErrorHandler, self);
				} else {
					self._updateEntryHandler(model, self.onApplyDetailUISuccess, EHexServiceUtil.onErrorHandler, self);
				}
			}
		});		
	} catch (e) {
		EHexServiceUtil.onErrorHandler(null, '500', e.message);
	}
};

AbstractDataListUI.prototype.onApplyDetailUISuccess = function(data, textStatus, jqXHR ) {
	var viewElement = $(this._entryId + '[id="' + data.id + '"]');
	if (viewElement == null || viewElement.length == 0) {
		viewElement = $(this._entryTemplateId).clone(true);
		if ($(this._listViewId).find('.tools').length > 0) {
			$(this._listViewId).find('.tools').before(viewElement);
		} else {
			$(this._listViewId).append(viewElement);	
		}
	}
	$(this._listViewId).find('.new-record').hide();

	data.hasWarnings = false;
	if (data.validationResult 
			&& ((data.validationResult.warnings && !$.isEmptyObject(data.validationResult.warnings)) 
					|| (data.validationResult.fieldWarnings && !$.isEmptyObject(data.validationResult.fieldWarnings)))) {
		data.hasWarnings = true;
	}
	this.toListView(data, viewElement);
	this.filterEntries();
	this.sortEntries();
	this.hideDetailUI();
};

AbstractDataListUI.prototype.confirmDelete = function(model, callback) {
	if (model.id != null && model.id != '') {
		var label = model.label;
		if (label == null) {
			label = model.name;
			if (label == null) {
				label = model.id;
			}
		}
		
		EHexDialogUI.confirm('Sind Sie sicher, dass Sie den Eintrag ' + "„" + label + "“" + ' entfernen möchten?', callback);
	}
};

AbstractDataListUI.prototype.confirmDirty = function(callback, message) {
	var self = this;
	
	if (this._dirty) {	
		if(!message) {
			message = 'Möchten Sie Ihre nicht gespeicherten Änderungen verwerfen?';
		}
		EHexDialogUI.confirm(message, function(result) {
			if (result) {
				self._dirty = false;
			}
			callback(result);
		}); 
	} else {
		callback(true);
	}
};

AbstractDataListUI.prototype.confirmWarnings = function(validationResult, callback) {
	var self = this;
	
	if (validationResult && validationResult.errors && !$.isEmptyObject(validationResult.errors)) {
		$.each(validationResult.errors, function(key, error) {
			EHexAlertUI.showError(error);
		});
		callback(false);
	} else {
		if ($(this._detailViewId).find('.warning').length > 0) {		
			EHexDialogUI.confirm('Sind Sie sicher, dass Sie die Daten trotz der Warnungen übernehmen möchten?', function(result) {
				callback(result);
			}); 
		} else {
			callback(true);
		}		
	}
};

AbstractDataListUI.prototype.deleteDetailUI = function(source) {
	var self = this;
	
	var model = {};
	if (source) {
		model.id = $(source).closest(self._entryId).attr('id');
		model.label = $(source).closest(self._entryId).attr('label');
		if ($(source).find('.ic').hasClass('disabled')) {
			return;
		}
	} else if (this._detailViewId) {
		var viewElement = $(this._detailViewId);
		this.toModel(viewElement, model);
	} else {
		return;
	}
	
	self.beforeRemoveCallback(model, function(references) {
		if (references && references.length > 0) {
			var label = model.label;
			if (label == null) {
				label = model.name;
				if (label == null) {
					label = model.id;
				}
			}
			
			var criticalRefs = new Array();
			var optionalRefs = new Array();
			
			for (var i = 0; i < references.length; i++) {
				var reference = references[i];
				if (reference.decoupler == null) {
					criticalRefs.push(reference);
				} else {
					optionalRefs.push(reference);
				}				
			}
				
			var message;
			var entry = 'Eintrag ' + "„" + label + "“";
			if (criticalRefs.length > 0) {
				title = 'Der Eintrag kann nicht gelöscht werden!';
				message = 'Kritische Referenz auf ' + entry + '.\n';
				for (var i = 0; i < criticalRefs.length; i++) {
					message += '\n';
					message += criticalRefs[i].label;					
				}
				
				if (optionalRefs.length > 0) {
					message += '\n\nZusätzlich wird der Eintrag von folgenden Objekten referenziert:\n'
					for (var i = 0; i < optionalRefs.length; i++) {
						message += '\n';
						message += optionalRefs[i].label;					
					}
				}
				EHexDialogUI.message(title, message);
			} else {
				if (optionalRefs.length > 0) {
					message = entry + ' wird verwendet:\n';
					for (var i = 0; i < optionalRefs.length; i++) {
						message += '\n';
						message += optionalRefs[i].label;					
					}
					message += '\n\nACHTUNG: Alle bestehenden Referenzen werden ebenfalls entfernt, wenn Sie fortfahren!'; 
					
					EHexDialogUI.confirm(message, function(result) {
						if (result) {
							self._removeEntryHandler(model, self.onDeleteDetailUISuccess, EHexServiceUtil.onErrorHandler, self, true);
						}
					});
				}
			}
		} else {
			self.confirmDelete(model, function(result) {
				if (result) {
					self._removeEntryHandler(model, self.onDeleteDetailUISuccess, EHexServiceUtil.onErrorHandler, self);
				}
			});	
		}
	});
};

AbstractDataListUI.prototype.beforeRemoveCallback = function(model, callback) {
	var self = this;
	
	if (self._beforeRemoveEntryHandler) {
		self._beforeRemoveEntryHandler(model, callback, EHexServiceUtil.onErrorHandler, self);
	} else {
		callback();
	}
};

AbstractDataListUI.prototype.onDeleteDetailUISuccess = function(data, textStatus, jqXHR ) {
	if (!this._detailViewId) {
		return;
	}
	
	var viewElement = $(this._detailViewId);
	var model = {};
	
	this.toModel(viewElement, model);
	$(this._entryId + '[id="' + model.id+ '"]').remove();
	
	this.sortEntries();
	this.hideDetailUI();
};

AbstractDataListUI.prototype.selectEntry = function(source, model) {
	var self = this;	
	
	this.confirmDirty(function(result) {
		if (result) {			
			if (self._detailViewId) {
				if (self._showDetailOnSelect) {
					self.showDetailUI(source, null, model);	
				} else {
					self.hideDetailUI();
				}
			} 
			$(source).closest(self._listViewId).find('.new-record').hide();			
			$(source).closest(self._listViewId).find(self._entryId).removeClass('active');
			$(source).closest(self._listViewId).find('.tools').removeClass('active');
			$(source).closest(self._entryId).addClass('active');
		}
	});
};

AbstractDataListUI.prototype.sortEntries = function() {
	var self = this;
	
	var entries = $(this._listViewId).find(this._entryId);
	entries.sort(function(a, b) {
		var labelA = $(a).attr(self._sortBy).toLowerCase();
		var labelB = $(b).attr(self._sortBy).toLowerCase();
		if (labelA > labelB) {
			return 1;
		} else if (labelA < labelB) {
			return -1;
		} else {
			return 0;
		}
	});
	$(this._listViewId).remove(this._entryId);
	if ($(this._listViewId).find('.tools').length > 0) {
		$(this._listViewId).find('.tools').before(entries);
	} else {
		$(this._listViewId).append(entries);
	}
	self.updateFilterCounter();
};

AbstractDataListUI.prototype.onFilterChanged = function(filterText) {
	var self = this;
	
	if (this._listViewId) {
		if (filterText && filterText != '') {
			
			var expr = new RegExp(filterText, 'i');
			
			
			var detailElement = $(this._detailViewId);
				
			if(detailElement.is(":visible")) {
				var model = {};
				this.toModel(detailElement, model);
				var listElement = $(this._listViewId+' [id="' + model.id + '"]');
				
					
				if (!listElement.attr('label').match(expr) && (!listElement.attr('description') || !listElement.attr('description').match(expr))) {
					if(this._dirty) {
						this.confirmDirty(
								function(result) {
									if (result) {			
										self.hideDetailUI();
										self.filterEntries(expr);
									}
								},
								'Der Filter beeinflusst den aktuell ausgewählten Eintrag. Dieser enthält aber noch ungespeicherte änderungen.\n Möchten Sie Ihre nicht gespeicherten Änderungen verwerfen und den Filter anwenden?'
						);
					}
					else {
						self.hideDetailUI();
						this.filterEntries(expr);	
					}
				}
				else {
					this.filterEntries(expr);	
				}
			}
			else {
				this.filterEntries(expr);	
			}
		}
		else {
			$(this._listViewId + ' .filtered').removeClass('filtered').show();
		}
	}
	self.updateFilterCounter();
};

AbstractDataListUI.prototype.filterEntries = function(expr) {
	if (expr === undefined) {
		var filterText = $(this._contentId).find('.list-filter input[name="filter"]').val();
		if (filterText && filterText != '') {
			expr = new RegExp(filterText, 'i');	
		} else {
			return;
		}
	}
	if (this._listViewId) {
		$(this._listViewId+' '+ this._entryId).each(function() {
			var listElement = $(this);
			if ((!listElement.attr('label') || !listElement.attr('label').match(expr)) && (!listElement.attr('description') || !listElement.attr('description').match(expr))) {
				listElement.addClass('filtered').hide();
			}
			else {
				listElement.removeClass('filtered').show();
			}
		});
	}
};

AbstractDataListUI.prototype.clearFilter = function() {
	$(this._contentId).find('.list-filter input[name="filter"]').val('');
};

AbstractDataListUI.prototype.updateFilterCounter = function() {
	var totalCount = $(this._listViewId).find(this._entryId).length;
	var visibleCount = $(this._listViewId).find(this._entryId + ':not(.filtered)').length;
	
	var filterCountText = totalCount + ' ' + (totalCount == 1 ? 'Datensatz' : 'Datensätze');
	if (visibleCount != totalCount) {
		filterCountText = visibleCount + ' ' + (visibleCount == 1 ? 'Datensatz' : 'Datensätze') + ' (Gesamt: ' + filterCountText + ')';
	}
	
	$(this._contentId).find('.filter-counter').text(filterCountText);
};

AbstractDataListUI.prototype.toListView = function(model, viewElement) {
	var self = this;
	
	viewElement.click(function() {
		self.selectEntry(this);
	});
	
	if (model.hasWarnings === true) {
		viewElement.addClass('warning');
	} else {
		viewElement.removeClass('warning');
	}
	
	viewElement.find('.protected').removeClass('protected-on protected-off');
	viewElement.find('.protected').addClass(model['protected'] === true ? 'protected-on' : 'protected-off');
	
	if (model['protected'] === true) {
		viewElement.find('.toolbar-delete .ic').addClass('disabled');	
	} else {
		viewElement.find('.toolbar-delete .ic').removeClass('disabled');
	}
	
	viewElement.css('display', 'block');			
};

AbstractDataListUI.prototype.toDetailView = function(model, viewElement) {
	$(this._detailViewId).find('.warning').removeClass('warning');
	this.initProtectedFields(model);
};

AbstractDataListUI.prototype.toModel = function(viewElement, model) {
	var validationResult = {warnings: {}, fieldWarnings : {}, errors: {}};
	return validationResult;
};

AbstractDataListUI.prototype.validate = function(model) {
	var self = this;
	
	if (!self._validateEntryHandler || !self._detailViewId) {
		return;
	}
	
	self._validateEntryHandler(
		model, 
		this.onValidateSuccess,
		EHexServiceUtil.onErrorHandler,
		self);
};

AbstractDataListUI.prototype.onValidateSuccess = function(data, textStatus, jqXHR) {
	var self = this;
	
	$(self._detailViewId).find('.warning').removeClass('warning');
	$(self._detailViewId).find('div .status.help').each(function() {
		$(this).attr('data-original-title', $(this).attr('info'));
	});
	
	
	var model = {};
	var localValidationResult = self.toModel($(self._detailViewId), model);
	if (localValidationResult) {
		if (!data) {
			data = localValidationResult;
		} else {
			if (localValidationResult.warnings) {
				if (data.warnings) {
					$.each(localValidationResult.warnings, function(key, item) {
						var entry = data.warnings[key];
						if (!entry) {
							entry = [];
						}
						data.warnings[key] = $.merge(entry, item);
					});
				} else {
					data.warnings = localValidationResult.warnings;
				}
			}
			
			if (localValidationResult.fieldWarnings) {
				if (data.fieldWarnings) {
					$.each(localValidationResult.fieldWarnings, function(key, item) {
						var entry = data.fieldWarnings[key];
						if (!entry) {
							entry = [];
						}
						data.fieldWarnings[key] = $.merge(entry, item);
					});
				} else {
					data.fieldWarnings = localValidationResult.fieldWarnings;
				}
			}
		}
	}
	
	if (data && data.warnings) {
		$.each(data.warnings, function(key, item) {
			console.log("WARNING: " + key + " : " + item);			
		});
	}
	if (data && data.fieldWarnings) {
		$.each(data.fieldWarnings, function(key, item) {
			var text = '';
			for (var i = 0; i < item.length; i++) {
				text += (i > 0 ? ' ' : '');
				if (EHexWarnings[item[i].warningId]) {
					text += EHexWarnings[item[i].warningId].text;
				} else {
					text += item[i].warningId;
				}
				
				if (item[i].additionalText) {
					text += ' ' + item[i].additionalText;
				}
			}
			console.log("WARNING: " + key + " : " + text);
			$(self._detailViewId).find('div' + self._entryId + '-' + key).addClass('warning');
			$(self._detailViewId).find('div' + self._entryId + '-' + key).find('.status.help').attr('data-original-title', text);
		});
	}
	
	var activeStatusField = $(self._detailViewId).find('div .status.help:focus, div .status.help:active');
	var tooltip = activeStatusField.attr('data-original-title');
	if (tooltip != null && tooltip != '') {
		activeStatusField.tooltip('show');	
	} else {
		activeStatusField.tooltip('hide');
	}	
};

AbstractDataListUI.prototype.onEntriesSuccess = function(data, textStatus, jqXHR ) {
	var self = this;
	
	$(this._listViewId).find(this._entryId).remove();
	$.each(data, function(key, entry) {
		var viewElement = $(self._entryTemplateId).clone(true);
		$(self._listViewId).append(viewElement);
		self.toListView(entry, viewElement);				
	});
	
	this.sortEntries();
};

AbstractDataListUI.prototype.onEntrySuccess = function(data, textStatus, jqXHR ) {
	var viewElement =  $(this._detailViewId);
	this.toDetailView(data, viewElement);
	this.onValidateSuccess(data.validationResult, textStatus, jqXHR)
	if(data.id != null && data.id != '') {
		this._dirty = false;	
	} else {
		this._dirty = true;
	}
};

AbstractDataListUI.prototype.initSelectBox = function(source, target, value, allowEmpty) {
	target.empty();
	
	if (allowEmpty && allowEmpty === true) {
		target.append('<option value=""></option>');
	}
	
	var selectGroup = null;
	$.each(source, function(key, entry) {
		var selected = (entry.value === value ? ' selected="selected" ' : '');
		
		var parent;
		if (entry.group) {
			if (target.find('optgroup[label="' + entry.group + '"]').length == 0) {
				target.append('<optgroup label="' + entry.group + '"></optgroup>');
			}
			parent = target.find('optgroup[label="' + entry.group + '"]');
		} else {
			parent = target;
		}
		parent.append('<option ' + selected + ' value=' + entry.value + '>' + entry.label + '</option>');
	});
};

AbstractDataListUI.prototype.initSelectData = function(source, target) {
	$.each(source, function(key, item) {
		var entry = {};
		entry.value = key;
		entry.label = (item.label ? item.label : item);
		if (item.data) {
			entry.data = item.data;
		}
		if (item.group) {
			entry.group = item.group;
		}
		target.push(entry);
	});
	
	target.sort(function(a, b) {
		var labelA = $(a).attr('label');
		var labelB = $(b).attr('label');
		if (labelA > labelB) {
			return 1;
		} else if (labelA < labelB) {
			return -1;
		} else {
			return 0;
		}
	});
};

AbstractDataListUI.prototype.initProtectedFields = function(model) {
	$(this._detailViewId).find('.protected-field').each(function(key, element) {
		var field = $(element);
		if (model['protected'] === true) {
			field.prop('disabled', true);
			field.find('input').prop('disabled', true);
			field.addClass('protected-field-on');
			field.find('input').addClass('protected-field-on');
			
		} else {
			field.prop('disabled', false);
			field.find('input').prop('disabled', false);
			field.removeClass('protected-field-on');
			field.find('input').removeClass('protected-field-on');
		}
	});	
	if (model.id != null && model.id != '') {
		if (model['protected'] === true) {
			$(this._detailViewId).find('.lock-entry').hide();
			$(this._detailViewId).find('.unlock-entry').show();
		} else {
			$(this._detailViewId).find('.lock-entry').show();
			$(this._detailViewId).find('.unlock-entry').hide();
		}
		$(this._detailViewId).find('.clone-entry').show();
	} else {
		$(this._detailViewId).find('.lock-entry').hide();
		$(this._detailViewId).find('.unlock-entry').hide();
		$(this._detailViewId).find('.clone-entry').hide();
	}
};

AbstractDataListUI.prototype.lockEntry = function(source) {
	var self = this;
	
	var model = {};
	if (source) {
		model.id = $(source).closest(self._entryId).attr('id');
		model.label = $(source).closest(self._entryId).attr('label');			
	} else if (this._detailViewId) {
		var viewElement = $(this._detailViewId);
		this.toModel(viewElement, model);
	} else {
		return;
	}
	
	if (self._lockEntryHandler) {
		self._lockEntryHandler(
				model, 
				function(data, textStatus, jqXHR) {
					self.refreshEntry(data);
				}, 
				EHexServiceUtil.onErrorHandler, 
				self
			);
	}
};

AbstractDataListUI.prototype.unlockEntry = function(source) {
	var self = this;
	
	var model = {};
	if (source) {
		model.id = $(source).closest(self._entryId).attr('id');
		model.label = $(source).closest(self._entryId).attr('label');			
	} else if (this._detailViewId) {
		var viewElement = $(this._detailViewId);
		this.toModel(viewElement, model);
	} else {
		return;
	}
	
	if (self._unlockEntryHandler) {
		self._unlockEntryHandler(
				model, 
				function(data, textStatus, jqXHR) {
					self.refreshEntry(data);
				}, 
				EHexServiceUtil.onErrorHandler, 
				self
			);
	}
};

AbstractDataListUI.prototype.cloneEntry = function(source) {
	var self = this;
	
	var model = {};
	if (source) {
		model.id = $(source).closest(self._entryId).attr('id');
		model.label = $(source).closest(self._entryId).attr('label');			
	} else if (this._detailViewId) {
		var viewElement = $(this._detailViewId);
		this.toModel(viewElement, model);
	} else {
		return;
	}
	
	if (self._cloneEntryHandler) {
		self._cloneEntryHandler(
				model, 
				function(data, textStatus, jqXHR) {
					self.refreshEntry(data);
				}, 
				EHexServiceUtil.onErrorHandler, 
				self
			);
	}
};


AbstractDataListUI.prototype.refreshEntry = function(model) {
	var viewElement = $(this._entryId + '[id="' + model.id + '"]');
	model.hasWarnings = false;
	if (model.validationResult 
			&& ((model.validationResult.warnings && !$.isEmptyObject(model.validationResult.warnings)) 
					|| (model.validationResult.fieldWarnings && !$.isEmptyObject(model.validationResult.fieldWarnings)))) {
		model.hasWarnings = true;
	}
	this.toListView(model, viewElement);
	this.sortEntries();
	this.hideDetailUI();
	this.selectEntry(viewElement, model)
};
