function PuppetryClientTerminalUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = 'Aufrufkontext';
	this._contentId = '.runtime-client';
	this._listViewId = '.terminal-list';
	this._entryId = '.terminal';
	this._entryTemplateId = '#terminal-template';
	this._sortBy = 'label';
	this._detailViewId = '.terminal-detail';
	
	this._clientId = null;
	this._clientName = null;
	
	this._listEntryHandler = function(success, error, context) {
		PuppetryClientTerminalsService.getTerminals(this._clientId, success, error, context);
	};
	
	this._newEntryHandler = function(success, error, context) {
		PuppetryClientTerminalsService.newTerminal(this._clientId, success, error, context);
	};
	
	this._getEntryHandler = function(id, success, error, context) {
		PuppetryClientTerminalsService.getTerminal(this._clientId, id, success, error, context);
	};
	
	this._updateEntryHandler = function(terminal, success, error, context) {
		PuppetryClientTerminalsService.updateTerminal(this._clientId, terminal, success, error, context);
	};
	
	this._addEntryHandler = function(terminal, success, error, context) {
		PuppetryClientTerminalsService.addTerminal(this._clientId, terminal, success, error, context);
	};
	
	this._removeEntryHandler = function(terminal, success, error, context) {
		PuppetryClientTerminalsService.removeTerminal(this._clientId, terminal, success, error, context);
	};
	
	this._beforeRemoveEntryHandler = function(terminal, success, error, context) {
		PuppetryClientTerminalsService.resolveTerminalReferences(this._clientId, terminal, success, error, context);
	};
	
	this._validateEntryHandler = function(terminal, success, error, context) {
		PuppetryClientTerminalsService.validateTerminal(this._clientId, terminal, success, error, context);
	};
	

};

//Create the prototype
PuppetryClientTerminalUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryClientTerminalUI.prototype.constructor = PuppetryClientTerminalUI;

PuppetryClientTerminalUI.prototype.showUI = function(source, detail) {
	if (source) {
		var client = $(source).closest('.client');
		this._clientId = client.attr('id');
		this._clientDisabled = client.find('.object-icon').hasClass('disabled');
		this._clientName = client.attr('label') + (this._clientDisabled == true ? ' (inaktive)' : '');

		$('.admin-mode > .header').html('<span class="font-20"><a href="#" onclick="Puppetry.showClients();">' + this._header + '</a> &lt; </span><span class="font-50"><a href="#" onclick="Puppetry.currentController().showUI();">' + this._clientName + '</a>');
		
		var addItem = $('#add-item-toolbar-template').clone(true);
		addItem.removeAttr('id');
		$('.admin-mode > .toolbar-container').append(addItem);
	}
	if ($('#wrapper').hasClass('live-mode')) {
		$('#wrapper').removeClass('live-mode').addClass('admin-mode');
		$('.live-mode').hide();
	}
	$('.admin-content').hide();
	$(this._contentId).show();
	
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
};

PuppetryClientTerminalUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	var self = this;
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.name);
	viewElement.find('.terminal-name').text(model.name);
	viewElement.find('.protected').addClass(model['protected'] === true ? 'protected-on' : 'protected-off');

	viewElement.find('.terminal-name').renamable({
		renaming: function(oldValue, newValue, success, error) {
			PuppetryClientTerminalsService.renameTerminal(self._clientId, model.id, newValue, success, error, self);
		},
		success : function(data, textStatus, jqXHR) {
			self.toListView(data, $(self._listViewId).find(self._entryId + '[id="' + data.id + '"]'));
			self.sortEntries();
			self.hideDetailUI();
		},
		error : EHexServiceUtil.onErrorHandler
	});
};

PuppetryClientTerminalUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	detailView.find('input.terminal-ctId').val(model.ctId);
	detailView.find('input.terminal-name').val(model.name);
	detailView.find('input.mac').val(model.macAddress);
	detailView.find('input.ipv4address').val(model.ipv4Address);
	detailView.find('input.ipv6address').val(model.ipv6Address);
	detailView.find('input.local').prop('checked', model.local != null ? model.local === true : true);
	detailView.find('input.physical').prop('checked', model.physical != null ? model.physical === true : true);

	if (model.id != null && model.id != '') {
		detailView.attr('terminal-id', model.id);
	} else {
		detailView.removeAttr('terminal-id');
	}
};

PuppetryClientTerminalUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	model.id = $('.terminal-detail').attr('terminal-id');
	model.ctId = $('.terminal-detail').find('input.terminal-ctId').val();
	model.name = $('.terminal-detail').find('input.terminal-name').val();

	model.macAddress = $('.terminal-detail').find('input.mac').val();
	model.ipv4Address = $('.terminal-detail').find('input.ipv4address').val();
	model.ipv6Address = $('.terminal-detail').find('input.ipv6address').val();
	model.local = $('.terminal-detail').find('input.local').is(':checked');
	model.physical = $('.terminal-detail').find('input.physical').is(':checked');
	model.numberOfSlots = 4;
	
	if (model.ctId == null || model.ctId == '') {
		validationResult.errors.name = 'Das Feld "Terminal-ID" ist verpflichtend!';
	}
	
	if (model.name == null || model.name == '') {
		validationResult.errors.name = 'Das Feld "Name" ist verpflichtend!';
	}
	
	return validationResult;
};

PuppetryClientTerminalUI.prototype.usePrototypeTerminalData = function(viewElement) {
	var self = this;
	var ctId = $(viewElement).val();

	PuppetryClientTerminalsService.getPrototypeTerminal(
			this._clientId, 
			ctId, 
			function(data, textStatus, jqXHR) {
				if(data != null && data != undefined) {
					EHexDialogUI.confirm(
							'Es existiert bereits ein Terminal mit der ID ' + "„" + ctId + "“" + ' in einem anderen Aufrufkontext.<br/>'+
							'Wollen Sie die Daten des bestehenden Terminals übernehmen?<br/><br/>'+
							'Die Verwendung der gleichen ID bei mehreren Terminals führt dazu, dass diese Terminals bzgl. der gesteckten Karten unabhängig vom verwendeten Aufrufkontext synchronisiert werden.',							
							function() {
								var detailView = $(viewElement).parents('.terminal-detail');
								detailView.find('input.terminal-name').val(data.name);
								detailView.find('input.mac').val(data.macAddress);
								detailView.find('input.ipv4address').val(data.ipv4Address);
								detailView.find('input.ipv6address').val(data.ipv6Address);
								detailView.find('input.local').prop('checked', data.local != null ? data.local === true : true);
								detailView.find('input.physical').prop('checked', data.physical != null ? data.physical === true : true);
							}
					);
				}
			}, 
			EHexServiceUtil.onErrorHandler, 
			self);
};


