function PuppetryClientUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = 'Aufrufkontext';
	this._contentId = '.client-content';
	this._listViewId = '.client-list';
	this._entryId = '.client';
	this._entryTemplateId = '#client-template';
	this._sortBy = 'label';
	this._detailViewId = '.client-detail';
	this._menuItemId = '.admin-client';
	
	this._listEntryHandler = PuppetryClientService.getClients;
	this._getEntryHandler = PuppetryClientService.getClient;
	this._newEntryHandler = PuppetryClientService.newClient;
	this._updateEntryHandler = PuppetryClientService.updateClient;
	this._addEntryHandler = PuppetryClientService.addClient;
	this._beforeRemoveEntryHandler = PuppetryClientService.resolveClientReferences;
	this._removeEntryHandler = PuppetryClientService.removeClient;
	this._validateEntryHandler = PuppetryClientService.validateClient;
};

//Create the prototype
PuppetryClientUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryClientUI.prototype.constructor = PuppetryClientUI;

PuppetryClientUI.prototype.showUI = function(source, detail) {
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
	
	$('.admin-mode > .header').text(this._header);
	
	var addItem = $('#add-item-toolbar-template').clone(true);
	addItem.removeAttr('id');
	$('.admin-mode > .toolbar-container').append(addItem);
	
	if ($('#wrapper').hasClass('live-mode')) {
		$('#wrapper').removeClass('live-mode').addClass('admin-mode');
		$('.live-mode').hide();
	}
	$('.admin-content').hide();
	$(this._contentId).show();
};

PuppetryClientUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	var self = this;
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.label);
	viewElement.find('.client-name').text(model.label);	
	
	var description = model.principalId + ' / ' + model.clientSystemId + ' / ' + model.workplaceId
	viewElement.find('.client-description').text(description);
	viewElement.attr('description', description);	
	
	var terminalCount;
	if (model.terminal) {
		if (typeof(model.terminal) == 'object') {
			terminalCount = model.terminal.length;
		} else {
			terminalCount = model.terminal;
		}
	} else {
		terminalCount = 0;
	}
	viewElement.find('.client-terminal-count').text(terminalCount);
	
	viewElement.find('.client-name').renamable({
		renaming: function(oldValue, newValue, success, error) {
			PuppetryClientService.renameClient(model.id, newValue, success, error, self);
		},
		success : function(data, textStatus, jqXHR) {
			self.toListView(data, $('.client-list').find('.client[id="' + data.id + '"]'));
			self.sortEntries();
			self.hideDetailUI();
		},
		error : EHexServiceUtil.onErrorHandler
	});
};

PuppetryClientUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	if (model.id != null && model.id != '') {
		detailView.attr('client-id', model.id);				
	} else {
		detailView.removeAttr('client-id');
	}
	
	if (model.label != null && model.label != '') {
		detailView.attr('label', model.label);
	} else {
		detailView.removeAttr('label');
	}
	
	if (model['protected'] != null && model['protected'] != '') {
		detailView.attr('protected', model['protected']);
	} else {
		detailView.removeAttr('protected');
	}
	
	detailView.find('input.principal').val(model.principalId);
	detailView.find('input.client-system').val(model.clientSystemId);
	detailView.find('input.workplace').val(model.workplaceId);
};

PuppetryClientUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	model.id = viewElement.attr('client-id');

	model.principalId = viewElement.find('.principal').val();
	model.clientSystemId = viewElement.find('.client-system').val();
	model.workplaceId = viewElement.find('.workplace').val();
	
	model.label = viewElement.attr('label');
	if ((model.label == null || model.label == '')
			&& (model.principalId != null && model.principalId != '')
			&& (model.clientSystemId != null && model.clientSystemId != '')
			&& (model.workplaceId != null && model.workplaceId != '')) {
		model.label = '';
		model.label += model.principalId;
		model.label += ' / ';
		model.label += model.clientSystemId;
		model.label += ' / ';
		model.label += model.workplaceId;
	}
	
	if (model.principalId == null || model.principalId == '') {
		validationResult.errors.principalId = 'Das Feld "Mandant" ist verpflichtend!';
	}
	
	if (model.clientSystemId == null || model.clientSystemId == '') {
		validationResult.errors.clientSystemId = 'Das Feld "Clientsystem" ist verpflichtend!';
	}
	
	if (model.workplaceId == null || model.workplaceId == '') {
		validationResult.errors.workplaceId = 'Das Feld "Arbeitsplatz" ist verpflichtend!';
	}
	
	return validationResult;
};
