function PuppetryClientSystemUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = 'Client-Authentifizierung';
	this._contentId = '.clientsystem-content';
	this._listViewId = '.clientsystem-list';
	this._entryId = '.clientsystem';
	this._entryTemplateId = '#clientsystem-template';
	this._sortBy = 'sorting';
	this._detailViewId = '.clientsystem-detail';
	this._menuItemId = '.common-connector-clientsystem-authentication';
	
	this._listEntryHandler = PuppetryClientSystemService.getClientSystems;
	this._getEntryHandler = PuppetryClientSystemService.getClientSystem;
	this._newEntryHandler = null;
	this._updateEntryHandler = PuppetryClientSystemService.updateClientSystem;
	this._addEntryHandler = null;
	this._beforeRemoveEntryHandler = null;
	this._removeEntryHandler = null;
	this._validateEntryHandler = PuppetryClientSystemService.validateClientSystem;
};

//Create the prototype
PuppetryClientSystemUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryClientSystemUI.prototype.constructor = PuppetryClientSystemUI;

PuppetryClientSystemUI.prototype.initUI = function() {
	AbstractDataListUI.prototype.initUI.call(this);
	
	var self = this;
	
	$(self._detailViewId).find('.truststoreName').dropzone({
		url : function (files) {
			var clientId = $(self._detailViewId).attr('clientsystem-id');
			return '../clientsystem/' + clientId + '/authentication/truststore';
		},
		method : 'put',
		clickable : '.clientsystem-detail .truststoreUpload',
		previewTemplate : '<div style="display: none"></div>',
		acceptedFiles: '.p12,.cer,.der,.crt',
		success: function(data, textStatus, jqXHR) {
			var clientId = $(self._detailViewId).attr('clientsystem-id');
			self._getEntryHandler(clientId, self.onEntrySuccess, EHexServiceUtil.onErrorHandler, self);
		},
		error: function(data, txtStatus, jqXHR) {
			EHexServiceUtil.onErrorHandler(txtStatus, txtStatus);
		}
	});
	
	$(self._detailViewId).find('.truststoreName').change(function() {
		self.onTruststoreChange(this);
	});
	
	$(self._detailViewId).find('.password').click(function(event) {
		var source = $(this);
		if (event.offsetX >= source.width() - 25 && event.offsetX <= source.width() && event.offsetY >= 0 && event.offsetY <= source.height()) {
			if (source.attr('type') == 'password') {
				$(this).attr('type', 'text');
			} else  {
				$(this).attr('type', 'password');
			}
		}
	});
};

PuppetryClientSystemUI.prototype.showUI = function(source, detail) {
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
	
	if ($('#wrapper').hasClass('admin-mode')) {
		$('.admin-mode > .header').html(this._header);
		$('.admin-content').hide();
	} else {
		$('.live-mode > .header').html(this._header);
		$('.live-content').hide();
	}

	$(this._contentId).show();
};

PuppetryClientSystemUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	var self = this;
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.label);
	viewElement.attr('standard', model.standard);	
	viewElement.find('.clientsystem-name').text(model.label);
	viewElement.find('.clientsystem-description').text(model.description);
	
	if (model.standard === true) {
		viewElement.addClass('standard');		
	}
	
	viewElement.attr('sorting', model.standard === true ? '1_' + model.label : '2_' + model.label);
};

PuppetryClientSystemUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	if (model.id != null && model.id != '') {
		detailView.attr('clientsystem-id', model.id);				
	} else {
		detailView.removeAttr('clientsystem-id');
	}
	
	if (model.label != null && model.label != '') {
		detailView.attr('label', model.label);
	} else {
		detailView.removeAttr('label');
	}
	
	if (model['protected'] != null && model['protected'] != '') {
		detailView.attr('protected', model['protected']);
	} else {
		detailView.removeAttr('protected');
	}
	
	detailView.find('input.client-system').val(model.clientSystemId);
	
	detailView.find('input.authenticationDataOverride').prop('disabled', model.standard != null ? model.standard : false);	
	detailView.find('input.authenticationDataOverride').prop('checked', model.authenticationDataOverride != null ? model.authenticationDataOverride : false);
	detailView.find('input.username').val(model.authenticationData != null ? model.authenticationData.username : null);
	detailView.find('input.password').val(model.authenticationData != null ? model.authenticationData.password : null);
	
	var truststoreName = model.authenticationData != null ? model.authenticationData.truststoreName : null;
	detailView.find('input.truststoreName').val(truststoreName);
	
	this.onTruststoreChange();
};

PuppetryClientSystemUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	model.id = viewElement.attr('clientsystem-id');

	model.clientSystemId = viewElement.find('.client-system').val();
	
	model.label = viewElement.attr('label');	
	model.authenticationDataOverride = viewElement.find('.authenticationDataOverride').is(':checked');
	
	var username = viewElement.find('.username').val();
	var password = viewElement.find('.password').val();
	var truststoreName = viewElement.find('.truststoreName').val();
	model.authenticationData = {username: username};
	if (truststoreName != null && truststoreName != '') {
		model.authenticationData.truststoreName = truststoreName
	}
	if (password != null && password != '') {
		model.authenticationData.password = password
	}
	
	if (model.clientSystemId == null || model.clientSystemId == '') {
		validationResult.errors.clientSystemId = 'Das Feld "Clientsystem" ist verpflichtend!';
	}
	
	return validationResult;
};

PuppetryClientSystemUI.prototype.getTruststore = function(source) {
	var clientSystemId = $(this._detailViewId).attr('clientsystem-id');
	
	PuppetryClientSystemService.getTruststore(
			clientSystemId, 
			function(data, textStatus, jqXHR) {
				// Do nothing
			}, 
			EHexServiceUtil.onErrorHandler);
};

PuppetryClientSystemUI.prototype.generateTruststore = function(source) {
	var self = this;
	var clientSystemId = $(self._detailViewId).attr('clientsystem-id');			
	
	EHexDialogUI.showWait('Zertifikat wird generiert...');
	
	PuppetryClientSystemService.generateTruststore(
			clientSystemId, 
			function(data, textStatus, jqXHR) {
				EHexDialogUI.hideWait();
				var authenticationData = data.authenticationData;
				$(self._detailViewId).find('.truststoreName').val(authenticationData != null ? authenticationData.truststoreName : null);
				self.onTruststoreChange();
			}, 
			EHexServiceUtil.onErrorHandler);
};

PuppetryClientSystemUI.prototype.deleteTruststore = function(source) {
	var self = this;
	var clientSystemId = $(self._detailViewId).attr('clientsystem-id');			
				
	PuppetryClientSystemService.deleteTruststore(
			clientSystemId, 
			function(data, textStatus, jqXHR) {
				var authenticationData = data.authenticationData;
				$(self._detailViewId).find('.truststoreName').val(authenticationData != null ? authenticationData.truststoreName : null);
				self.onTruststoreChange();
			}, 
			EHexServiceUtil.onErrorHandler);
};

PuppetryClientSystemUI.prototype.onTruststoreChange = function(source) {
	var self = this;
	
	if (!source) {
		source = $(self._detailViewId).find('.truststoreName');
	}
	
	var truststoreName = $(source).val();
	var clientSystemId = $(self._detailViewId).attr('clientsystem-id');
	var isProtected = $(self._detailViewId).attr('protected') === 'true';
	
	var truststoreAllowed = clientSystemId != null && clientSystemId != ''&& !isProtected;
	var truststoreUploadAllowed = truststoreAllowed;
	var truststoreGenerateAllowed = truststoreAllowed;
	var truststoreDownloadAllowed = truststoreAllowed && truststoreName != null && truststoreName != '';
	var truststoreDeleteAllowed = truststoreAllowed && truststoreName != null && truststoreName != '';
	
	$(self._detailViewId).find('.truststoreUpload').prop('disabled', !truststoreUploadAllowed);
	$(self._detailViewId).find('.truststoreDownload').prop('disabled', !truststoreDownloadAllowed);
	$(self._detailViewId).find('.truststoreGenerate').prop('disabled', !truststoreGenerateAllowed);
	$(self._detailViewId).find('.truststoreDelete').prop('disabled', !truststoreDeleteAllowed);
};
