function PuppetryConnectorSettingsUI() {
	this._header = '<span class="font-20">Konnektor &lt; </span><span class="font-50">Einstellungen</span>';
	this._contentId = '.connector-settings-content';
	this._menuItemId = '.common-connector-settings';
	this._dirty = false;
	
	this._sdsStatus = new Array();
	this._authenticationMechanism = new Array();
	this._cetpAuthenticationMechanism = new Array();

	this._eventClientBehaviour = new Array();
}
		
PuppetryConnectorSettingsUI.prototype.initUI = function() {
	var self = this;	
	
	$(this._contentId).find('input,select,textarea').change(function() {
		self._dirty = true;
	});
	
	$(this._contentId).find('input.connector-sds-open-active').change(function() {
		self.onSDSOpenChange();		
	});
	
	$(this._contentId).find('input.connector-service-open-active').change(function() {
		self.onConnectorServiceOpenActiveChange();
	});
	
	PuppetryConnectorService.getSDSStatus(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self._sdsStatus);
	}, EHexServiceUtil.onErrorHandler, this);
	
	PuppetryConnectorService.getAuthenticationMechanisms(function(data, textStatus, jqXHR) {
		
		var serviceData = {};
		var cetpData = {};
		$.each(data, function(key, item) {
			if (key != 'NONE') {
				serviceData[key] = item;
			}
			if (key != 'BASIC_AUTH') {
				cetpData[key] = item;
			}
		});
		
		self.initSelectData(serviceData, self._authenticationMechanism);
		self.initSelectData(cetpData, self._cetpAuthenticationMechanism);
	}, EHexServiceUtil.onErrorHandler, this);

	PuppetryConnectorService.getEventClientBehaviour(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self._eventClientBehaviour);
	}, EHexServiceUtil.onErrorHandler, this);
};

PuppetryConnectorSettingsUI.prototype.showUI = function() {
	var self = this;
	
	if ($('#wrapper').hasClass('admin-mode')) {
		$('.admin-mode > .header').html(this._header);
		$('.admin-content').hide();
	} else {
		$('.live-mode > .header').html(this._header);
		$('.live-content').hide();
	}
	
	var detailHeight = $(window).height() - $('.navbar.navbar-default').height();
	$(this._contentId).css('min-height', detailHeight);			
	$(this._contentId).show();
	
	$(this._contentId).find('ul.nav-tabs li.active').removeClass('active');
	$(this._contentId).find('ul.nav-tabs').find(':first-child').addClass('active');
	$('.connector-settings-tab-connection').css('display', 'block');
	$('.connector-settings-tab-event').css('display', 'none');
	$('.connector-settings-tab-common').css('display', 'none');	
	
	PuppetryConnectorService.getConnector(
			function(data, textStatus, jqXHR ) {
				self.toView(data);
			}, 
			EHexServiceUtil.onErrorHandler
		);
};

PuppetryConnectorSettingsUI.prototype.toView = function(model) {
	var self = this;
	
	this.initSelectBox(this._authenticationMechanism, $(this._contentId).find('select.connectorAuthenticationMechanism'), model.authenticationMechanism);
	this.initSelectBox(this._cetpAuthenticationMechanism, $(this._contentId).find('select.cetpAuthenticationMechanism'), model.cetpAuthenticationMechanism);
	
	$(this._contentId).find('.host').val(model.host);
	$(this._contentId).find('.port').val(model.port != null && model.port > 0 ? model.port : '');
	$(this._contentId).find('.open-port').val(model.httpPort != null && model.httpPort > 0 ? model.httpPort : '');
	
	$(this._contentId).find('input.connector-service-open-active').prop('checked', model.serviceOpen === true);
	this.onConnectorServiceOpenActiveChange();
	
	this.initSelectBox(this._sdsStatus, $(this._contentId).find('.sdsStatus'), model.sdsstatus);
	
	$(this._contentId).find('input.connector-sds-open-active').prop('checked', model.sdsopen === true);
	
	this.onSDSOpenChange($(this._contentId).find('input.connector-sds-open-active'));
	
	$(this._contentId).find('.defaultEventUrl').val(model.defaultEventUrl);
	$(this._contentId).find('.subscriptionTerminationTime').val(model.subscriptionTerminationTime);
	$(this._contentId).find('.liveProtocolInterval').val(model.liveProtocolInterval > 0 ? model.liveProtocolInterval : '');
	$(this._contentId).find('.autoRefreshInterval').val(model.autoRefreshInterval > 0 ? model.autoRefreshInterval : '');
	$(this._contentId).find('.suppressEvents')[0].checked = model.suppressEvents;
	this.initSelectBox(this._eventClientBehaviour, $(this._contentId).find('select.eventClientBehaviour'), model.eventClientBehaviour);
};

PuppetryConnectorSettingsUI.prototype.showTabConnectionUI = function(source) {
	$('.connector-settings-tab-connection').css('display', 'block');
	$('.connector-settings-tab-event').css('display', 'none');
	$('.connector-settings-tab-common').css('display', 'none');	
};

PuppetryConnectorSettingsUI.prototype.showTabEventUI = function(source) {
	$('.connector-settings-tab-connection').css('display', 'none');
	$('.connector-settings-tab-event').css('display', 'block');
	$('.connector-settings-tab-common').css('display', 'none');
};

PuppetryConnectorSettingsUI.prototype.showTabCommonUI = function(source) {
	$('.connector-settings-tab-connection').css('display', 'none');
	$('.connector-settings-tab-event').css('display', 'none');
	$('.connector-settings-tab-common').css('display', 'block');
};

PuppetryConnectorSettingsUI.prototype.applyChanges = function(source) {	
	try {
		var self = this;
		
		EHexDialogUI.showWait('Einstellungen werden übernommen...');
		
		var authenticationMechanism = $(this._contentId).find('select.connectorAuthenticationMechanism').val();
		var cetpAuthenticationMechanism = $(this._contentId).find('select.cetpAuthenticationMechanism').val();
		var host = $(this._contentId).find('.host:not([readonly])').val();
		var port = $(this._contentId).find('.port').val();
		if (port != null && port != '') {
			if (!$.isNumeric(port) || Math.floor(port) != port) {
				throw new Error('Bitte geben Sie einen gültigen Port ein!');
			}	
		}

		var serviceOpen = $(this._contentId).find('input.connector-service-open-active').is(':checked');
		var openPort = $(this._contentId).find('.open-port').val();
		if (openPort != null && openPort != '') {
			if (!$.isNumeric(openPort) || Math.floor(openPort) != openPort) {
				throw new Error('Bitte geben Sie einen gültigen ungesicherten Port ein!');
			}	
		}
		
		var sdsStatus = $(this._contentId).find('.sdsStatus').val();
		var sdsOpen = $(self._contentId).find('input.connector-sds-open-active').is(':checked');		
		
		var defaultEventUrl = $(this._contentId).find('.defaultEventUrl').val();
		if (defaultEventUrl != null && defaultEventUrl != '') {
			if (!/^cetp:\/\//.test(defaultEventUrl)) {
				throw new Error('Bitte geben Sie eine gültige URL für den statischen Ereignis-Endpunkt ein!')
			}
		}

		var eventClientBehaviour = $(this._contentId).find('select.eventClientBehaviour').val();
		
		var subscriptionTerminationTime = $(this._contentId).find('.subscriptionTerminationTime').val();
		if (subscriptionTerminationTime != null && subscriptionTerminationTime != '') {
			if (!$.isNumeric(subscriptionTerminationTime) || Math.floor(subscriptionTerminationTime) != subscriptionTerminationTime || subscriptionTerminationTime < 0) {
				throw new Error('Bitte geben Sie ein gültige Wert für die Gültigkeitsdauer einer Event-Subscription!');
			}	
		}

		var liveProtocolInterval = $(this._contentId).find('.liveProtocolInterval').val();
		if (liveProtocolInterval != null && liveProtocolInterval != '') {
			if (!$.isNumeric(liveProtocolInterval) || Math.floor(liveProtocolInterval) != liveProtocolInterval || liveProtocolInterval < 0) {
				throw new Error('Bitte geben Sie ein gültiges Aktualisierungsintervall für das Live-Protokoll ein!');
			}	
		}
		
		var autoRefreshInterval = $(this._contentId).find('.autoRefreshInterval').val();
		if (autoRefreshInterval != null && autoRefreshInterval != '') {
			if (!$.isNumeric(autoRefreshInterval) || Math.floor(autoRefreshInterval) != autoRefreshInterval || autoRefreshInterval < 0) {
				throw new Error('Bitte geben Sie ein gültiges Intervall für die Aktualisierung der Anzeige ein!');
			}	
		} 

		var suppressEvents = $(this._contentId).find('.suppressEvents').is(':checked');
		
		var settings = {};
		settings.defaultEventUrl = defaultEventUrl;
		settings.subscriptionTerminationTime = subscriptionTerminationTime;
		settings.liveProtocolInterval = liveProtocolInterval;
		settings.autoRefreshInterval = autoRefreshInterval;
		settings.suppressEvents = suppressEvents;
		settings.eventClientBehaviour = eventClientBehaviour;
		settings.host = host;
		settings.port = port;
		settings.httpPort = openPort;
		settings.sdsStatus = sdsStatus;
		settings.sdsOpen = sdsOpen;
		settings.authenticationMechanism = authenticationMechanism;
		settings.serviceOpen = serviceOpen;
		settings.cetpAuthenticationMechanism = cetpAuthenticationMechanism;
	
		PuppetryConnectorService.setSettings(
				settings,
				function(data, textStatus, jqXHR) {
					self.toView(data);
					
					EHexDialogUI.hideWait();
					self._dirty = false;
				}, 
				EHexServiceUtil.onErrorHandler
			);
		
	} catch (e) {
		EHexServiceUtil.onErrorHandler(null, '500', e.message);
	}
}; 

PuppetryConnectorSettingsUI.prototype.downloadTLSCert = function(source) {
	PuppetryConnectorService.getTLSCert(source);
},

PuppetryConnectorSettingsUI.prototype.cancelChanges = function(source) {
	this.showUI();
	this._dirty = false;
};

PuppetryConnectorSettingsUI.prototype.confirmDirty = function(callback) {
	var self = this;
	
	if (this._dirty) {		
		EHexDialogUI.confirm('Möchten Sie Ihre nicht gespeicherten Änderungen verwerfen?', function(result) {
			if (result) {
				self._dirty = false;
			}
			callback(result);
		}); 
	} else {
		callback(true);
	}
};

PuppetryConnectorSettingsUI.prototype.onConnectorServiceOpenActiveChange = function() {
	var self = this;
	var serviceOpen = $(this._contentId).find('input.connector-service-open-active').is(':checked');
	var openPort = $(this._contentId).find('input.open-port');
	
	if(serviceOpen) {
		openPort.prop('disabled', false);
		$(this._contentId).find('input.connector-sds-open-active').prop('checked', true);
	}
	else {
		openPort.prop('disabled', true);
	}
	
	self.updateSDS();
};

PuppetryConnectorSettingsUI.prototype.onSDSOpenChange = function() {
	var self = this;
	self.updateSDS();
};

PuppetryConnectorSettingsUI.prototype.updateSDS = function() {
	var self = this;
	
	var serviceOpen = $(this._contentId).find('input.connector-service-open-active').is(':checked');
	var sdsOpen = $(this._contentId).find('input.connector-sds-open-active').is(':checked');
	
	var sdsHost = $(this._contentId).find('.host:not([readonly])').val();
	if (sdsHost === 'localhost' || sdsHost === '0.0.0.0') {
		sdsHost = window.location.hostname;
		if(sdsHost === 'localhost') {
			sdsHost = '127.0.0.1';
		}
	}	
	
	if (serviceOpen === true || sdsOpen === true) {
		var sdsOpenUrl = 'http://' + sdsHost + ':80/connector.sds';	
		$(self._contentId).find('.connector-sds-open-url').html('<a href="' + sdsOpenUrl + '" target="_blank">' + sdsOpenUrl + '</a>');
		$(self._contentId).find('.connector-sds-open').show();
	} else {
		$(self._contentId).find('.connector-sds-open').hide();
	}
	
	var sdsSecureUrl = 'https://' + sdsHost + ':443/connector.sds';
	$(self._contentId).find('.connector-sds-secure-url').html('<a href="' + sdsSecureUrl + '" target="_blank">' + sdsSecureUrl + '</a>');
	$(self._contentId).find('.connector-sds-secure').show();

	if (!serviceOpen) {
		$(this._contentId).find('input.connector-sds-open-active').prop('disabled', false);
	} else {
		$(this._contentId).find('input.connector-sds-open-active').prop('disabled', true);
	}
}

PuppetryConnectorSettingsUI.prototype.initSelectBox = function(source, target, value, allowEmpty) {
	target.empty();
	
	if (allowEmpty && allowEmpty === true) {
		target.append('<option value=""></option>');
	}
	
	var selectGroup = null;
	$.each(source, function(key, entry) {
		var selected = (entry.value === value ? ' selected="selected" ' : '');
		
		var parent;
		if (entry.group) {
			if (target.find('optgroup[label="' + entry.group + '"]').length == 0) {
				target.append('<optgroup label="' + entry.group + '"></optgroup>');
			}
			parent = target.find('optgroup[label="' + entry.group + '"]');
		} else {
			parent = target;
		}
		parent.append('<option ' + selected + ' value=' + entry.value + '>' + entry.label + '</option>');
	});
};

PuppetryConnectorSettingsUI.prototype.initSelectData = function(source, target) {
	$.each(source, function(key, item) {
		var entry = {};
		entry.value = key;
		entry.label = (item.label ? item.label : item);
		if (item.data) {
			entry.data = item.data;
		}
		if (item.group) {
			entry.group = item.group;
		}
		target.push(entry);
	});
	
	target.sort(function(a, b) {
		var labelA = $(a).attr('label');
		var labelB = $(b).attr('label');
		if (labelA > labelB) {
			return 1;
		} else if (labelA < labelB) {
			return -1;
		} else {
			return 0;
		}
	});
};
