function PuppetryEhcUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = '<span class="font-20">Karten &lt; </span><span class="font-50">Versichertenkarten</span>';
	this._contentId = '.ehc-content';
	this._listViewId = '.ehc-list';
	this._entryId = '.ehc';
	this._entryTemplateId = '#ehc-template';
	this._sortBy = 'label';
	this._detailViewId = '.ehc-detail';
	this._menuItemId = '.admin-ehc';
	
	this._listEntryHandler = PuppetryEHCService.getEHCs;
	this._getEntryHandler = PuppetryEHCService.getEHC;
	this._newEntryHandler = PuppetryEHCService.newEHC;
	this._updateEntryHandler = PuppetryEHCService.updateEHC;
	this._addEntryHandler = PuppetryEHCService.addEHC;
	this._beforeRemoveEntryHandler = PuppetryEHCService.getEHCReferences;
	this._removeEntryHandler = PuppetryEHCService.removeEHC;
	this._validateEntryHandler = PuppetryEHCService.validateEHC;
	this._cloneEntryHandler = PuppetryEHCService.cloneEHC;
	
	this.pinStatus = new Array();
	this.statusPNs = new Array();
	this.genders = new Array();
	this.insuranceTypes = new Array();
	this.schemaVersions = new Array();
	this.cardTypes = new Array();
};

//Create the prototype
PuppetryEhcUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryEhcUI.prototype.constructor = PuppetryEhcUI;

PuppetryEhcUI.prototype.initUI = function() {
	AbstractDataListUI.prototype.initUI.call(this);
	
	var self = this;
	
	PuppetrySMCBService.getPinStatus(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self.pinStatus);
	}, EHexServiceUtil.onErrorHandler, this);
	
	PuppetryEHCService.getPNs(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self.statusPNs);
	}, EHexServiceUtil.onErrorHandler, this);
	
	PuppetryEHCService.getGenders(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self.genders);
	}, EHexServiceUtil.onErrorHandler, this);
		
	PuppetryEHCService.getInsuranceTypes(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self.insuranceTypes);
	}, EHexServiceUtil.onErrorHandler, this);
	
	PuppetryEHCService.getSchemaVersions(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self.schemaVersions);
	}, EHexServiceUtil.onErrorHandler, this);
	
	this.cardTypes.push({value: 'EHC', label: 'eGK G2'});
	this.cardTypes.push({value: 'EHC_G21', label: 'eGK G2.1'});
	this.cardTypes.push({value: 'EHC_G1P', label: 'eGK G1+'});
	this.cardTypes.push({value: 'KVK', label: 'KVK'});
	this.cardTypes.push({value: 'UNKNOWN', label: 'UNKNOWN'});
	
	PuppetryEHCService.getEHCs(this.onEntriesSuccess, EHexServiceUtil.onErrorHandler, this);
};

PuppetryEhcUI.prototype.showUI = function(source, detail) {
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
	
	$('.admin-mode > .header').html(this._header);
	
	var addItem = $('#add-item-toolbar-template').clone(true);
	addItem.removeAttr('id');
	$('.admin-mode > .toolbar-container').append(addItem);
	
	if ($('#wrapper').hasClass('live-mode')) {
		$('#wrapper').removeClass('live-mode').addClass('admin-mode');
		$('.live-mode').hide();
	}
	$('.admin-content').hide();
	$(this._contentId).show();	
};

PuppetryEhcUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	var self = this;
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.label);
	if (model.description) {
		viewElement.attr('description', model.description);	
	} else {
		viewElement.removeAttr('description');
	}
	viewElement.find('.ehc-name').text(model.label);
	viewElement.find('.ehc-description').text(model.description ? model.description : '<Keine Beschreibung vorhanden>');

	viewElement.find('.ehc-name').renamable({
		renaming: function(oldValue, newValue, success, error) {
			PuppetryEHCService.renameEHC(model.id, newValue, success, error, self);
		},
		success : function(data, textStatus, jqXHR) {
			self.toListView(data, $('.ehc-list').find('.ehc[id="' + data.id + '"]'));
			self.sortEntries();
			self.hideDetailUI();
		},
		error : EHexServiceUtil.onErrorHandler
	});
};

PuppetryEhcUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	this.initSelectBox(this.pinStatus, detailView.find('.initialpinstatus'), model.initialPinStatus);
	
	var isProtected = model['protected'] === true;
	
	this.initSelectBox(this.statusPNs, detailView.find('.status-pn'), model.status != null ? model.status.pn : '');
	this.initSelectBox(this.insuranceTypes, detailView.find('.insuranceType'), model.data != null ? model.data.insuranceType : '');
	this.initSelectBox(this.schemaVersions, detailView.find('.schemaVersion'), model.data != null ? model.data.schemaVersion : '');
	
	this.initSelectBox(this.genders, detailView.find('.gender'), model.data != null ? model.data.gender : '');
	
	this.initSelectBox(this.cardTypes, detailView.find('.cardType'), model.cardType);

	detailView.find('.ehc-name').val(model.label);
	detailView.find('.iccsn').val(model.iccsn);
	detailView.find('.description').val(model.description);
	detailView.find('.givenName').val(model.data != null ? model.data.givenName : '');
	detailView.find('.surname').val(model.data != null ? model.data.surname : '');
	detailView.find('.insuredId').val(model.data != null ? model.data.insuredId : '');
	detailView.find('.insuranceId').val(model.data != null ? model.data.insuranceId : '');
	detailView.find('.insuranceName').val(model.data != null ? model.data.insuranceName : '');
	detailView.find('.zuzahlungsStatus').prop('checked',  model.xmlData != null ? model.data.zuzahlungsStatus : false);

	detailView.find('.ehc-pd-override').prop('checked', model.xmlData != null ? model.xmlData.pdOverride : false);
	detailView.find('.ehc-pd').prop('disabled', isProtected || (model.xmlData != null ? !model.xmlData.pdOverride : true));
	detailView.find('.ehc-pd').val(model.xmlData != null && model.xmlData.pd != null ? atob(model.xmlData.pd) : '');
	detailView.find('.ehc-pd-version').val(model.xmlData != null ? model.xmlData.pdVersion : '');
	detailView.find('input[type="checkbox"].ehc-pdCompress').prop('checked', model.xmlData != null ? model.xmlData.pdCompress : true);

	detailView.find('.ehc-vd-override').prop('checked', model.xmlData != null ? model.xmlData.vdOverride : false);
	detailView.find('.ehc-vd').prop('disabled', isProtected || (model.xmlData != null ? !model.xmlData.vdOverride : true));
	detailView.find('.ehc-vd').val(model.xmlData != null && model.xmlData.vd != null ? atob(model.xmlData.vd) : '');
	detailView.find('.ehc-vd-version').val(model.xmlData != null ? model.xmlData.vdVersion : '');
	detailView.find('input[type="checkbox"].ehc-vdCompress').prop('checked', model.xmlData != null ? model.xmlData.vdCompress : true);

	detailView.find('.ehc-gvd-override').prop('checked',  model.xmlData != null ? model.xmlData.gvdOverride : false);
	detailView.find('.ehc-gvd').prop('disabled', isProtected || (model.xmlData != null ? !model.xmlData.gvdOverride : true));
	detailView.find('.ehc-gvd').val(model.xmlData != null && model.xmlData.gvd != null ? atob(model.xmlData.gvd) : '');
	detailView.find('.ehc-gvd-version').val(model.xmlData != null ? model.xmlData.gvdVersion : '');
	detailView.find('input[type="checkbox"].ehc-gvdCompress').prop('checked', model.xmlData != null ? model.xmlData.gvdCompress : true);

	detailView.find('.ehc-pn-override').prop('checked',  model.xmlData != null ? model.xmlData.pnOverride : false);
	detailView.find('.ehc-pn').prop('disabled', isProtected || (model.xmlData != null ? !model.xmlData.pnOverride : true));
	detailView.find('.ehc-pn').val(model.xmlData != null && model.xmlData.pn != null ? atob(model.xmlData.pn) : '');
	detailView.find('.ehc-pn-version').val(model.xmlData != null ? model.xmlData.pnVersion : '');
	detailView.find('input[type="checkbox"].ehc-pnCompress').prop('checked', model.xmlData != null ? model.xmlData.pnCompress : true);

	detailView.find('.status-toggleData').prop('checked', model.status != null ? model.status.toggleData : false);
	detailView.find('.certexpirationdate').val(model.certExpirationDate != null ? $.datepicker.formatDate('dd.mm.yy', new Date(model.certExpirationDate)) : '');
	detailView.find('.dateOfBirth').val(model.data != null && model.data.dateOfBirth != null ? $.datepicker.formatDate('dd.mm.yy', new Date(model.data.dateOfBirth)) : '');
	detailView.find('.startOfInsurance').val(model.data != null && model.data.startOfInsurance != null ? $.datepicker.formatDate('dd.mm.yy', new Date(model.data.startOfInsurance)) : '');
	detailView.find('.endOfInsurance').val(model.data != null && model.data.endOfInsurance != null ? $.datepicker.formatDate('dd.mm.yy', new Date(model.data.endOfInsurance)) : '');
	detailView.find('.lastUpdate').val(model.data != null && model.data.lastUpdate != null ? $.datepicker.formatDate('dd.mm.yy', new Date(model.data.lastUpdate)) : '');

	if (model.id != null && model.id != '') {
		detailView.attr('ehc-id', model.id);
	} else {
		detailView.removeAttr('ehc-id');
	}

	$('ul.nav-tabs.ehc-detail-tabs li.active').removeClass('active');
	$('ul.nav-tabs.ehc-detail-tabs').find(':first-child').addClass('active');
	
	$('ul.nav-tabs.ehc-detail-xml-tabs li.active').removeClass('active');
	$('ul.nav-tabs.ehc-detail-xml-tabs').find(':first-child').addClass('active');
	detailView.find('.ehc-detail-xml .tab-content .tab-pane').removeClass('active in');
	detailView.find('.ehc-detail-xml .tab-content .tab-pane:first').addClass('active in');
};

PuppetryEhcUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	model.data = {};
	model.status = {};
	model.xmlData = {};
	
	model.id = viewElement.attr('ehc-id');
	model.iccsn = viewElement.find('.iccsn').val();
	model.initialPinStatus = viewElement.find('.initialpinstatus').val();	
	model.label = viewElement.find('.ehc-name').val();
	model.description = viewElement.find('.description').val();

	model.cardType = viewElement.find('.cardType').val();

	model.data.givenName =  viewElement.find('.givenName').val();
	model.data.surname =  viewElement.find('.surname').val();
	model.data.gender =  viewElement.find('.gender').val();
	model.data.insuredId =  viewElement.find('.insuredId').val();
	model.data.insuranceId = viewElement.find('.insuranceId').val();
	model.data.insuranceName =  viewElement.find('.insuranceName').val();
	model.data.insuranceType =  viewElement.find('.insuranceType').val();
	model.data.schemaVersion =  viewElement.find('.schemaVersion').val();
	model.data.zuzahlungsStatus = viewElement.find('.zuzahlungsStatus').is(':checked');
	model.status.pn = viewElement.find('.status-pn').val();
	model.status.toggleData = viewElement.find('.status-toggleData').is(':checked');	
	
	model.xmlData.pdOverride = viewElement.find('.ehc-pd-override').is(':checked');
	if (model.xmlData.pdOverride === true) {
		var pd = viewElement.find('.ehc-pd').val();
		if (pd != null && pd != '') {
			model.xmlData.pd = btoa(pd);
		}
	}
	model.xmlData.pdCompress = viewElement.find('input[type="checkbox"].ehc-pdCompress').is(':checked');

	model.xmlData.vdOverride = viewElement.find('.ehc-vd-override').is(':checked');
	if (model.xmlData.vdOverride === true) {
		var vd = viewElement.find('.ehc-vd').val();
		if (vd != null && vd != '') {
			model.xmlData.vd = btoa(vd);
		}
	}
	model.xmlData.vdCompress = viewElement.find('input[type="checkbox"].ehc-vdCompress').is(':checked');

	model.xmlData.gvdOverride = viewElement.find('.ehc-gvd-override').is(':checked');
	if (model.xmlData.gvdOverride === true) {
		var gvd = viewElement.find('.ehc-gvd').val();
		if (gvd != null && gvd != '') {
			model.xmlData.gvd = btoa(gvd);
		}
	}
	model.xmlData.gvdCompress = viewElement.find('input[type="checkbox"].ehc-gvdCompress').is(':checked');

	model.xmlData.pnOverride = viewElement.find('.ehc-pn-override').is(':checked');
	if (model.xmlData.pnOverride === true) {
		var pn = viewElement.find('.ehc-pn').val();
		if (pn != null && pn != '') {
			model.xmlData.pn = btoa(pn);
		}
	}
	model.xmlData.pnCompress = viewElement.find('input[type="checkbox"].ehc-pnCompress').is(':checked');

	var certExpirationDate = viewElement.find('.certexpirationdate').val();
	if (certExpirationDate != null && certExpirationDate != '') {
		try {
			model.status.certExpirationDate = $.datepicker.parseDate('dd.mm.yy', certExpirationDate).getTime();
		} catch (e) {
			var warning = [{warningId : 'INVALID'}];
			validationResult.fieldWarnings.certExpirationDate = warning;
		}
	}

	var dateOfBirth =  viewElement.find('.dateOfBirth').val();
	if (dateOfBirth != null && dateOfBirth != '') {
		try {
			model.data.dateOfBirth = $.datepicker.parseDate('dd.mm.yy', dateOfBirth).getTime();
		} catch (e) {
			var warning = [{warningId : 'INVALID'}];
			validationResult.fieldWarnings.dateOfBirth = warning;
		}
	}

	var startOfInsurance =  viewElement.find('.startOfInsurance').val();
	if (startOfInsurance != null && startOfInsurance != '') {
		try {
			model.data.startOfInsurance = $.datepicker.parseDate('dd.mm.yy', startOfInsurance).getTime();
		} catch (e) {
			var warning = [{warningId : 'INVALID'}];
			validationResult.fieldWarnings.startOfInsurance = warning;
		}
	}

	var endOfInsurance =  viewElement.find('.endOfInsurance').val();
	if (endOfInsurance != null && endOfInsurance != '') {
		try {
			model.data.endOfInsurance = $.datepicker.parseDate('dd.mm.yy', endOfInsurance).getTime();
		} catch (e) {
			var warning = [{warningId : 'INVALID'}];
			validationResult.fieldWarnings.endOfInsurance = warning;
		}
	}

	var lastUpdate =  viewElement.find('.lastUpdate').val();
	if (lastUpdate != null && lastUpdate != '') {
		try {
			model.data.lastUpdate = $.datepicker.parseDate('dd.mm.yy', lastUpdate).getTime();
		} catch (e) {
			var warning = [{warningId : 'INVALID'}];
			validationResult.fieldWarnings.lastUpdate = warning;
		}
	}
	
	if (model.label == null || model.label == '') {
		validationResult.errors.error = 'Das Feld "Label" ist verpflichtend!';
	}

	return validationResult;
};

PuppetryEhcUI.prototype.hideDetailUI = function() {
	AbstractDataListUI.prototype.hideDetailUI.call(this);

	$('.ehc-detail').prev().css('display', 'block');
	$('.ehc-detail-basic').removeClass('col-md-5').addClass('col-md-12');
	$('.ehc-detail-vsdm').css('display', 'none');
	$('.ehc-detail-xml').css('display', 'none');
};

PuppetryEhcUI.prototype.showBasicUI = function(source) {
	var self = this;
	
	$('.ehc-detail').prev()
		.css('display', 'block');
	$('.ehc-detail')
		.removeClass('col-md-12')
		.addClass(self._cssDetailColSize);

	$('.ehc-detail-basic').removeClass('col-md-5').addClass('col-md-12');
	
	$('.ehc-detail-vsdm').css('display', 'none');
	$('.ehc-detail-xml').css('display', 'none');
};

PuppetryEhcUI.prototype.showVsdmUI = function(source) {
	var self = this;
	
	$('.ehc-detail').prev()
		.css('display', 'none');
	$('.ehc-detail')
		.removeClass(self._cssDetailColSize)
		.addClass('col-md-12');

	$('.ehc-detail-basic').removeClass('col-md-12').addClass('col-md-5');

	$('.ehc-detail-vsdm').css('display', 'block');
	$('.ehc-detail-xml').css('display', 'none');
};

PuppetryEhcUI.prototype.showXmlUI = function(source) {
	var self = this;
	
	$('.ehc-detail').prev()
		.css('display', 'none');
	$('.ehc-detail')
		.removeClass(self._cssDetailColSize)
		.addClass('col-md-12');

	$('.ehc-detail-basic').removeClass('col-md-12').addClass('col-md-5');
	
	$('.ehc-detail-vsdm').css('display', 'none');
	$('.ehc-detail-xml').css('display', 'block');
};

PuppetryEhcUI.prototype.toggleOverridePd = function(source) {
	var detailView = $('.ehc-detail');
	var checked = detailView.find('.ehc-pd-override').is(':checked');
	detailView.find('.ehc-pd').attr('disabled', !checked);
};

PuppetryEhcUI.prototype.toggleOverrideVd = function(source) {
	var detailView = $('.ehc-detail');
	var checked = detailView.find('.ehc-vd-override').is(':checked');
	detailView.find('.ehc-vd').attr('disabled', !checked);
};

PuppetryEhcUI.prototype.toggleOverrideGvd = function(source) {
	var detailView = $('.ehc-detail');
	var checked = detailView.find('.ehc-gvd-override').is(':checked');
	detailView.find('.ehc-gvd').attr('disabled', !checked);
};

PuppetryEhcUI.prototype.toggleOverridePn = function(source) {
	var detailView = $('.ehc-detail');
	var checked = detailView.find('.ehc-pn-override').is(':checked');
	detailView.find('.ehc-pn').attr('disabled', !checked);
};

PuppetryEhcUI.prototype.onValidateSuccess = function(data, textStatus, jqXHR) {
	AbstractDataListUI.prototype.onValidateSuccess.call(this, data, textStatus, jqXHR);
	
	var self = this;
	
	if (data && data.fieldWarnings) {
		$.each(data.fieldWarnings, function(key, item) {
			if ($('.ehc-detail-basic').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-basic-toggle').addClass('warning');
			}
			if ($('.ehc-detail-vsdm').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-vsdm-toggle').addClass('warning');
			}
			if ($('.ehc-detail-xml').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-xml-toggle').addClass('warning');
			}
			
			if ($('#ehc-detail-pd').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-pd-toggle').addClass('warning');
			}
			if ($('#ehc-detail-vd').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-vd-toggle').addClass('warning');
			}
			if ($('#ehc-detail-gvd').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-gvd-toggle').addClass('warning');
			}
			if ($('#ehc-detail-pn').find('div' + self._entryId + '-' + key).length > 0) {
				$('.ehc-detail-pn-toggle').addClass('warning');
			}
		});
	}
};
