function PuppetryLiveClientServiceHookUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = 'Aufrufkontext';
	this._contentId = '.live-client-servicehook-content';
	this._listViewId = '.live-client-servicehook-list';
	this._entryId = '.live-client-servicehook';
	this._entryTemplateId = '#live-client-servicehook-template';
	this._sortBy = 'label';
	this._detailViewId = '.live-client-servicehook-detail';
	
	this._clientId = null;
	this._clientName = null;
	
	this._connectorServices = new Array();
	this._serviceInterceptions = new Array();
	
	this._listEntryHandler = function(success, error, context) {
		PuppetryClientServiceHookService.getServiceHooks(this._clientId, success, error, context);
	};
	
	this._newEntryHandler = function(success, error, context) {
		PuppetryClientServiceHookService.newServiceHook(this._clientId, success, error, context);
	};
	
	this._getEntryHandler = function(id, success, error, context) {
		PuppetryClientServiceHookService.getServiceHook(this._clientId, id, success, error, context);
	};
	
	this._updateEntryHandler = function(serviceHook, success, error, context) {
		PuppetryClientServiceHookService.updateServiceHook(this._clientId, serviceHook, success, error, context);
	};
	
	this._addEntryHandler = function(serviceHook, success, error, context) {
		PuppetryClientServiceHookService.addServiceHook(this._clientId, serviceHook, success, error, context);
	};
	
	this._removeEntryHandler = function(serviceHook, success, error, context) {
		PuppetryClientServiceHookService.removeServiceHook(this._clientId, serviceHook, success, error, context);
	};
	
	this._beforeRemoveEntryHandler = function(serviceHook, success, error, context) {
		PuppetryClientServiceHookService.resolveServiceHookReferences(this._clientId, serviceHook, success, error, context);
	};
	
	this._validateEntryHandler = function(serviceHook, success, error, context) {
		PuppetryClientServiceHookService.validateServiceHook(this._clientId, serviceHook, success, error, context);
	};

};

//Create the prototype
PuppetryLiveClientServiceHookUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryLiveClientServiceHookUI.prototype.constructor = PuppetryLiveClientServiceHookUI;

PuppetryLiveClientServiceHookUI.prototype.initUI = function() {
	AbstractDataListUI.prototype.initUI.call(this);
	
	var self = this;
	
	PuppetryClientServiceHookService.getConServices(function(data, textStatus, jqXHR ) {
		self.initSelectData(data, self._connectorServices);
	}, EHexServiceUtil.onErrorHandler);
	
	$(self._detailViewId).find('select.service').change(function() {
		self.onConServiceChange(this);		
	});

	$(self._detailViewId).find('select.serviceMethod').change(function() {
		self.onConMethodChange(this);		
	});
	
	$(self._detailViewId).find('select.serviceInterception').change(function() {
		self.onServiceInterceptionChange(this);		
	});
	
	PuppetryClientServiceHookService.getServiceInterceptions(function(data, textStatus, jqXHR ) {
		self.initSelectData(data, self._serviceInterceptions);
	}, EHexServiceUtil.onErrorHandler);
	
};

PuppetryLiveClientServiceHookUI.prototype.showUI = function(source, detail) {
	if (source) {
		var client = $(source).closest('.live-client');
		this._clientId = client.attr('id');
		this._clientDisabled = client.find('.object-icon').hasClass('disabled');
		this._clientName = client.attr('label') + (this._clientDisabled == true ? ' (inaktive)' : '');

		$('.live-mode > .header').html('<span class="font-20"><a href="#" onclick="Puppetry.showLiveClientUI();">' + this._header + '</a> &lt; </span><span class="font-50"><a href="#" onclick="Puppetry.currentController().showUI();">' + this._clientName + '</a>');
		
		var addItem = $('#add-item-toolbar-template').clone(true);
		addItem.removeAttr('id');
		$('.live-mode > .toolbar-container').append(addItem);
	}
	if ($('#wrapper').hasClass('admin-mode')) {
		$('#wrapper').removeClass('admin-mode').addClass('live-mode');
		$('.admin-mode').hide();
	}
	$('.live-content').hide();
	$(this._contentId).show();
	
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
};

PuppetryLiveClientServiceHookUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	var self = this;
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.label);
	viewElement.find('.servicehook-name').text(model.label);
	viewElement.find('.protected').addClass(model['protected'] === true ? 'protected-on' : 'protected-off');
		
	if(model.active === true) {
		viewElement.find('.object-icon').removeClass('disabled');
		viewElement.find('.servicehook-active').hide();
		viewElement.find('.servicehook-inactive').show();
	} else {
		viewElement.find('.object-icon').addClass('disabled');
		viewElement.find('.servicehook-active').show();
		viewElement.find('.servicehook-inactive').hide();
	}
	
	var description = '';
	if (model.serviceErrorText) {
		if (description != '') {
			description += ', ';
		}
		description += 'Fehler: ' + model.serviceErrorText;			
	}
	if (model.delayBefore > 0) {
		if (description != '') {
			description += ', ';
		}
		description += 'Verzögerung vor dem Aufruf: ' + model.delayBefore + 'ms';
	}
	if (model.delayAfter > 0) {
		if (description != '') {
			description += ', ';
		}
		description += 'Verzögerung nach dem Aufruf: ' + model.delayAfter + 'ms';
	}
	
	viewElement.find('.servicehook-description').text(description);
};

PuppetryLiveClientServiceHookUI.prototype.onApplyDetailUISuccess = function(data, statusText, jqXHR) {
	if (data.serviceError) {
		var serviceErrorText = $(this._detailViewId).find('select.serviceError option[value="' + data.serviceError + '"]').text();
		data.serviceErrorText = serviceErrorText;
	}
	AbstractDataListUI.prototype.onApplyDetailUISuccess.call(this, data, statusText, jqXHR);
};

PuppetryLiveClientServiceHookUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	this.initSelectBox(this._connectorServices, detailView.find('select.service'), model != null ? model.service : '', true);
	this.onConServiceChange(null, model);
	
	this.initSelectBox(this._serviceInterceptions, detailView.find('select.serviceInterception'), model != null ? model.interception : '', true);
	
	detailView.find('select.service').val(model.service);
	detailView.find('select.serviceMethod').val(model.serviceMethod);
	detailView.find('select.serviceError').val(model.serviceError);
	detailView.find('input.delayBefore').val(model.delayBefore > 0 ? model.delayBefore : '');
	detailView.find('input.delayAfter').val(model.delayAfter > 0 ? model.delayAfter : '');
	detailView.find('input.servicehook-active').prop('checked', model.active === true);	

	if (model.id != null && model.id != '') {
		detailView.attr('servicehook-id', model.id);
	} else {
		detailView.removeAttr('servicehook-id');
	}

	this.onServiceInterceptionChange(detailView.find('select.serviceInterception'), model);
	detailView.find('textarea.serviceInterceptionData').val(model.interceptionData ? model.interceptionData : '');	
};

PuppetryLiveClientServiceHookUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	var detailView = $(this._detailViewId); 
	model.id = detailView.attr('servicehook-id');
	
	model.serviceMethod = detailView.find('select.serviceMethod').val();
	if (model.serviceMethod == '') {
		model.serviceMethod = null;
	}
	
	model.serviceError = detailView.find('select.serviceError').val();
	if (model.serviceError == '') {
		model.serviceError = null;
	}
	
	model.interception = detailView.find('select.serviceInterception').val();
	if (model.interception == '') {
		model.interception = null;
	}
	
	model.interceptionData = detailView.find('textarea.serviceInterceptionData').val();
	if (model.interceptionData == '') {
		model.interceptionData = null;
	}
	
	model.delayBefore = detailView.find('input.delayBefore').val();
	if (model.delayBefore < 0) {
		model.delayBefore = 0;
	}
	
	model.delayAfter = detailView.find('input.delayAfter').val();
	if (model.delayAfter < 0) {
		model.delayAfter = 0;
	}
	
	model.active = detailView.find('input.servicehook-active').is(':checked');
	
	
	var service = detailView.find('select.service').val();
	if (service == null || service == '') {
		validationResult.errors.service = 'Das Feld "Dienst" ist verpflichtend!';
	}
	
	if (model.serviceMethod == null || model.serviceMethod == '') {
		validationResult.errors.serviceMethod = 'Das Feld "Methode" ist verpflichtend!';
	}
	
	return validationResult;
};

PuppetryLiveClientServiceHookUI.prototype.onConServiceChange = function(source, serviceHook) {
	var self = this;
	
	if (!source) {
		source = $(self._detailViewId).find('select.service');
	}
	
	$(self._detailViewId).find('select.serviceMethod').empty();
	$(self._detailViewId).find('select.serviceError').empty();
	
	var selectedConService = $(source).val();
	if (selectedConService != null && selectedConService != '') {
		$(self._detailViewId).find('select.serviceMethod').prop('disabled', false);
		
		PuppetryClientServiceHookService.getConMethods(selectedConService, function(data, textStatus, jqXHR ) {
			var serviceMethods = new Array();
			self.initSelectData(data, serviceMethods);
			
			self.initSelectBox(serviceMethods, $(self._detailViewId).find('select.serviceMethod'), '', true);
			$(self._detailViewId).find('select.serviceMethod').val(serviceHook != null ? serviceHook.serviceMethod : '');
			self.onConMethodChange(null, serviceHook);
		}, EHexServiceUtil.onErrorHandler);
	} else {
		$(self._detailViewId).find('input,select').not('select.service').prop('disabled', true);
	}
};

PuppetryLiveClientServiceHookUI.prototype.onConMethodChange = function(source, serviceHook) {
	var self = this;
	
	var selectedConService = $($(self._detailViewId).find('select.service')).val();
	
	if (!source) {
		source = $(self._detailViewId).find('select.serviceMethod');
	}

	$(self._detailViewId).find('select.serviceError').empty();
	
	var selectedConMethod = $(source).val();
	if (selectedConService != null && selectedConService != '' && selectedConMethod != null && selectedConMethod != '') {
		$(self._detailViewId).find('input,select').not('select.service,select.serviceMethod').prop('disabled', false);
		PuppetryClientServiceHookService.getConErrors(selectedConService, selectedConMethod, function(data, textStatus, jqXHR ) {
			var conErrors = new Array();
			self.initSelectData(data, conErrors);
			
			self.initSelectBox(conErrors, $(self._detailViewId).find('select.serviceError'), '', true);
			$(self._detailViewId).find('select.serviceError').val(serviceHook != null ? serviceHook.serviceError : '');
		}, EHexServiceUtil.onErrorHandler);
	} else {
		$(self._detailViewId).find('input,select').not('select.service,select.serviceMethod').prop('disabled', true);
	}
};

PuppetryLiveClientServiceHookUI.prototype.onServiceInterceptionChange = function(source, serviceHook) {
	var self = this;
	
	var interception = $(source).val();	
	if (interception == 'USER_DEFINED_RESPONSE') {
		var detailView = $(self._detailViewId);
		detailView.find('.live-client-servicehook-serviceInterceptionData').show();	
		detailView.find('textarea.serviceInterceptionData').outerHeight(detailView.outerHeight() - detailView.find('textarea.serviceInterceptionData').position().top - 20);				
	} else {
		$(self._detailViewId).find('.live-client-servicehook-serviceInterceptionData').hide();
	}
	$(self._detailViewId).find('textarea.serviceInterceptionData').val('');
}

PuppetryLiveClientServiceHookUI.prototype.activate = function(source, e) {
	if (e) {
		e.stopPropagation();	
	}	
	
	var self = this;

	var servicehookElmt = $(source).closest('.live-client-servicehook');
	var serviceHookId = servicehookElmt.attr('id');
	var clientId = this._clientId;
	
	PuppetryClientServiceHookService.changeServiceHookState(
			clientId,
			serviceHookId,
			true,
			function(data, textStatus, jqXHR) {
				servicehookElmt.find('.servicehook-active').hide();
				servicehookElmt.find('.servicehook-inactive').show();
				servicehookElmt.find('.object-icon').removeClass('disabled');
			},
			EHexServiceUtil.onErrorHandler
		);
};

PuppetryLiveClientServiceHookUI.prototype.deactivate = function(source, e) {
	if (e) {
		e.stopPropagation();	
	}	
	
	var self = this;

	var servicehookElmt = $(source).closest('.live-client-servicehook');
	var serviceHookId = servicehookElmt.attr('id');
	var clientId = this._clientId;
	
	PuppetryClientServiceHookService.changeServiceHookState(
			clientId,
			serviceHookId,
			false,
			function(data, textStatus, jqXHR) {
				servicehookElmt.find('.servicehook-active').show();
				servicehookElmt.find('.servicehook-inactive').hide();
				servicehookElmt.find('.object-icon').addClass('disabled');
			},
			EHexServiceUtil.onErrorHandler
		);
};
