function PuppetryLiveClientTerminalUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = 'Aufrufkontext';
	this._contentId = '.live-client-terminal-content';
	this._listViewId = '.live-client-terminal-list';
	this._entryId = '.live-client-terminal';
	this._entryTemplateId = '#live-client-terminal-template';
	this._sortBy = 'label';
	
	this._clientId = null;
	this._clientName = null;
	
	this._autoRefreshWorker = null;
	this._autoRefreshInterval = null;
	this._autoRefreshErrorCounter = 0;
};

//Create the prototype
PuppetryLiveClientTerminalUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryLiveClientTerminalUI.prototype.constructor = PuppetryLiveClientTerminalUI;

PuppetryLiveClientTerminalUI.prototype.initUI = function() {
	AbstractDataListUI.prototype.initUI.call(this);
	
	var self = this;
	
	$(this._contentId).find('.ehc-pattern').keyup(function() {
		var pattern = $(this).val();
		if (pattern != null && pattern != '') {
			$(self._contentId).find('.ehc-select-list').find('.basic-card').css('display', 'none');

			var re =  RegExp(pattern ,"i");
			$(self._contentId).find('.ehc-select-list').find('.basic-card').filter(function() {
				var label = $(this).attr('label');
				var desc = $(this).attr('description');
				return (label && re.test(label)) || (desc && re.test(desc));
			}).each(function() {
				$(this).css('display', 'block');
			});
		} else {
			$(self._contentId).find('.ehc-select-list').find('.basic-card').css('display', 'block');
		}
	});

	$(this._contentId).find('.smcb-pattern').keyup(function() {
		var pattern = $(this).val();
		if (pattern != null && pattern != '') {
			$(self._contentId).find('.smcb-select-list').find('.basic-card').css('display', 'none');

			var re =  RegExp(pattern ,"i");
			$(self._contentId).find('.smcb-select-list').find('.basic-card').filter(function() {
				var label = $(this).attr('label');
				var desc = $(this).attr('description');
				return (label && re.test(label)) || (desc && re.test(desc));
			}).each(function() {
				$(this).css('display', 'block');
			});
		} else {
			$(self._contentId).find('.smcb-select-list').find('.basic-card').css('display', 'block');
		}
	});

};

PuppetryLiveClientTerminalUI.prototype.adjustContent = function() {
	AbstractDataListUI.prototype.adjustContent.call(this);
	
	var self = this;

	var windowHeight = $(window).height();
	var navbarHeight = $('.navbar-fixed-top').outerHeight(true);
	var maxHeight = windowHeight > navbarHeight ? windowHeight : navbarHeight;
	
	var headerHeight = $('.navbar.navbar-default').outerHeight(true);
	var contentHeight = maxHeight - headerHeight;
	var detailHeaderHeight = $(self._contentId).find('.row.detail-header').outerHeight(true) + $(self._contentId).find('.search').outerHeight(true) + 15;
	
	$(self._contentId).find('.live-client-terminal-list').outerHeight(contentHeight);	
	$(self._contentId).find('.detail').outerHeight(contentHeight);
	
	$(self._contentId).find('.ehc-select-list').outerHeight(contentHeight - detailHeaderHeight);
	$(self._contentId).find('.smcb-select-list').outerHeight(contentHeight - detailHeaderHeight);
};

PuppetryLiveClientTerminalUI.prototype.showEHC = function(source) {
	$('.ehc-tab').css('display', 'block');
	$('.smcb-tab').css('display', 'none');
};

PuppetryLiveClientTerminalUI.prototype.showSMCB = function(source) {
	$('.smcb-tab').css('display', 'block');
	$('.ehc-tab').css('display', 'none');
};

PuppetryLiveClientTerminalUI.prototype.showUI = function(source, detail) {
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
	
	var self = this;
	
	if (source) {
		var client = $(source).closest('.live-client');
		this._clientId = client.attr('id');
		this._clientDisabled = client.find('.object-icon').hasClass('disabled');
		this._clientName = client.attr('label') + (this._clientDisabled == true ? ' (inaktive)' : '');

		$('.live-mode > .header').html('<span class="font-20"><a href="#" onclick="Puppetry.showLiveClientUI();">' + this._header + '</a> &lt; </span><span class="font-50"><a href="#" onclick="Puppetry.currentController().showUI();">' + this._clientName + '</a>');
	}
	if ($('#wrapper').hasClass('admin-mode')) {
		$('#wrapper').removeClass('admin-mode').addClass('live-mode');
		$('.admin-mode').hide();
	}
	$('.live-content').hide();
	$(this._contentId).show();
	
	this.adjustContent();
	this.syncCards('EHC');
	this.syncCards('SMCB');
	PuppetryLiveClientService.getTerminals(this._clientId, this.onEntriesSuccess, EHexServiceUtil.onErrorHandler, this);
	
	if (self._autoRefreshWorker) {
		clearInterval(self._autoRefreshWorker);
		self._autoRefreshWorker = null;
	}
	self._autoRefreshErrorCounter = 0;
	
	PuppetryConnectorService.getConnector(
		function(data, textStatus, jqXHR){
			if (self._autoRefreshInterval !== data.autRefreshInterval) {
				self._autoRefreshInterval = data.autoRefreshInterval;
				if (self._autoRefreshWorker) {
					clearInterval(self._autoRefreshWorker);
					self._autoRefreshWorker = null;
				}
			}
		
			if (self._autoRefreshInterval > 0 && !self._autoRefreshWorker) {
				self._autoRefreshWorker = setInterval(function() {
					if ($(self._listViewId).is(':visible')) {
						PuppetryLiveClientService.getTerminals(
								self._clientId, 
								function(data, textStatus, jqXHR) {
									$.each(data, function(key, terminal) {
										self.refreshCards(terminal);				
									});
								},
								function(jqXHR, textStatus, errorThrown) {
									self._autoRefreshErrorCounter++;
									EHexServiceUtil.onErrorHandler(jqXHR, textStatus, errorThrown);
									if (self._autoRefreshErrorCounter > 3) {
										clearInterval(self._autoRefreshWorker);
										self._autoRefreshWorker = null;
									}
								}, 
								self
							);	
					} else {
						clearInterval(self._autoRefreshWorker);
						self._autoRefreshWorker = null;
					}					
				}, self._autoRefreshInterval * 1000); 
			}
		},
		EHexServiceUtil.onErrorHandler,
		self
	);
};


PuppetryLiveClientTerminalUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.name);
	viewElement.find('.terminal-name').text(model.name);
	if(model.connected === true) {
		viewElement.find('.object-icon').removeClass('disabled');
		viewElement.find('.slots').show();
		viewElement.find('.terminal-connect').hide();
		viewElement.find('.terminal-disconnect').show();
	} else {
		viewElement.find('.object-icon').addClass('disabled');
		viewElement.find('.slots').hide();
		viewElement.find('.terminal-connect').show();
		viewElement.find('.terminal-disconnect').hide();
	}
	
	this.refreshCards(model);
};

PuppetryLiveClientTerminalUI.prototype.syncCards = function(cardType) {
	var self = this;
	
	var cardSelector = '.' + cardType.toLowerCase();
	$(this._contentId).find(cardSelector + '-select-list').empty();
	
	var appendCard = function(cardId, cardType, cardName, cardDesc, cardGotoAllowed) {
		var card = $('#card-template').clone(true);
		card.attr('id', cardId);
		card.attr('label', cardName);
		card.attr('type', cardType);
		if (cardDesc) {
			card.attr('description', cardDesc);
			card.attr('data-original-title', cardDesc)
		} 
		card.find('span').text(cardName);
		card.css('display','block');
		
		if (cardGotoAllowed !== true) {
			card.find('.ic-menu-settings').addClass('disabled');
		} else {
			card.find('.ic-menu-settings').removeClass('disabled');
		}
		
		$(self._contentId).find(cardSelector + '-select-list').append(card);
	};

	$(cardSelector + '-list').find(cardSelector).each(function(key, card) {
		var cardId = $(card).attr('id');
		var cardName = $(card).attr('label');
		var cardDesc = $(card).attr('description');
		appendCard(cardId, cardType, cardName, cardDesc, true);
	});
	
	$(self._contentId).find('.basic-card').tooltip();

	$(this._contentId).find(cardSelector + '-select-list').find('.card').draggable({
	  	helper: 'clone',
	  	snap: true,
	  	scroll: false,
	  	zIndex: 9999,
	  	appendTo: $(this._contentId).find(cardSelector + '-select-list'),
	  	containment : $(this._contentId),
	  	start: function (event, ui) {
	  	   $(this).data("startingScrollTop",window.pageYOffset);
	  	},
	  	drag: function(event,ui){
	  	   var st = parseInt($(this).data("startingScrollTop"));
	  	   ui.position.top += st;
	  	},
	});
};

PuppetryLiveClientTerminalUI.prototype.refreshCards = function(terminal) {
	var self = this;
	
	$(self._contentId).find('.tooltip').hide();
	
	$(self._contentId).find(self._listViewId).find(self._entryId + '[id="' + terminal.id + '"]').find('.slot')
		.removeAttr('id')
		.removeAttr('label')
		.removeAttr('type')
		.removeAttr('data-original-title')
		.addClass('empty-slot')
		.removeClass('plugged-card');
	
	$.each(terminal.cards, function(key, pluggedCard) {
		var cardName;
		var cardDescription;
		var cardType;
		var cardGotoAllowed;
		
		var cardId = pluggedCard.card.id;
		var card = $('.smcb[id="' + cardId + '"],.ehc[id="' + cardId + '"]');
		if (card && card.length > 0) {
			cardName = card.attr('label');
			cardDescription = card.attr('description') + '\n'+'PIN-Status: '+ pluggedCard.pinStatus;
			
			if (card.hasClass('ehc')) {
				cardType = 'EHC';
			} else if (card.hasClass('smcb')) {
				cardType = 'SMCB';
			}
			cardGotoAllowed = true;
		} 
	
		var slotElmt = $(self._contentId).find(self._listViewId).find(self._entryId + '[id="' + terminal.id + '"]').find('.slot[slot="' + key + '"]');
		slotElmt
			.attr('id', cardId)
			.attr('label', cardName)
			.attr('description', cardDescription)
			.attr('data-original-title', cardDescription)
			.attr('type', cardType)
			.removeClass('empty-slot')
			.addClass('plugged-card');
		slotElmt.find('.card')
			.html('<span>' + cardName + '</span>');
		
		if (cardGotoAllowed !== true) {
			slotElmt.find('.ic-menu-settings').addClass('disabled');
		} else {
			slotElmt.find('.ic-menu-settings').removeClass('disabled');
		}
		
		slotElmt.tooltip();
	});
	
	$(self._contentId).find(self._listViewId).find(self._entryId + '[id="' + terminal.id + '"]').find('.empty-slot').each(function (key, slot) {
		var slotId = $(slot).attr('slot');
		$(slot).find('.card').html('<span>' + slotId + '</span>');
	});
	
	$.each($(self._contentId).find(self._listViewId).find('.card'), function(key, value) {
		$(value).droppable({
			snap: true,
			hoverClass: 'card-drop-target',
			accept: function(el) {
				return el.closest('.basic-card').hasClass("basic-card") && $(this).closest('.slot').hasClass('empty-slot');
			},
			drop: function(event, ui) {
				var slot = $(event.target).closest('.slot');
				var card = $(ui.draggable).closest('.basic-card');
				self.insertCard(slot, card);
			}
		});
	});
	
	
};

PuppetryLiveClientTerminalUI.prototype.insertCard = function(slot, card) {
	var self = this;
	
	var terminalId = $(slot).closest(self._entryId).attr('id');
	var slotId = $(slot).attr('slot');
	var cardId = card.attr('id');
	
	var onInsertCardSuccess = function(data, textStatus, jqXHR ) {
		var terminal = data.terminal;
		self.refreshCards(terminal);
		EHexAlertUI.showInfo('Das Ereignis "Karte gesteckt" wurde ausgelöst. Weitere Aktionen müssen vom Primärsystem aus gesteuert werden.');
	};
	
	PuppetryLiveClientService.insertCard(this._clientId, terminalId, slotId, cardId, onInsertCardSuccess, EHexServiceUtil.onErrorHandler, self);
};

PuppetryLiveClientTerminalUI.prototype.ejectCard = function(source) {
	var self = this;
	
	var slot = $(source).closest('.slot');
	
	if (slot.hasClass('plugged-card')) {
		self.removeCard(slot);
	}
};

PuppetryLiveClientTerminalUI.prototype.removeCard = function(slot) {
	var self = this;
	
	var terminalId = $(slot).closest(self._entryId).attr('id');
	var slotId = $(slot).attr('slot');
	
	var onRemoveCardSuccess = function(data, textStatus, jqXHR ) {
		var terminal = data.terminal;
		self.refreshCards(terminal);
		EHexAlertUI.showInfo('Das Ereignis "Karte entfernt" wurde ausgelöst. Weitere Aktionen müssen vom Primärsystem aus gesteuert werden.');
	};
	
	PuppetryLiveClientService.removeCard(self._clientId, terminalId, slotId, onRemoveCardSuccess, EHexServiceUtil.onErrorHandler, self);
};

PuppetryLiveClientTerminalUI.prototype.connect = function(source, e) {
	var clientTerminalElmt = $(source).closest('.live-client-terminal');
	var terminalId = clientTerminalElmt.attr('id');
	var clientId = this._clientId;
	
	PuppetryLiveClientService.changeTerminalConnection(
			clientId,
			terminalId,
			true,
			function(data, textStatus, jqXHR) {
				clientTerminalElmt.find('.terminal-connect').hide();
				clientTerminalElmt.find('.terminal-disconnect').show();				
				clientTerminalElmt.find('.object-icon').removeClass('disabled');
				clientTerminalElmt.find('.slots').show();
			},
			EHexServiceUtil.onErrorHandler
		);
};

PuppetryLiveClientTerminalUI.prototype.disconnect = function(source, e) {
	var clientTerminalElmt = $(source).closest('.live-client-terminal');
	var terminalId = clientTerminalElmt.attr('id');
	var clientId = this._clientId;
	
	PuppetryLiveClientService.changeTerminalConnection(
			clientId,
			terminalId,
			false,
			function(data, textStatus, jqXHR) {
				clientTerminalElmt.find('.terminal-connect').show();
				clientTerminalElmt.find('.terminal-disconnect').hide();
				clientTerminalElmt.find('.object-icon').addClass('disabled');
				clientTerminalElmt.find('.slots').hide();
			},
			EHexServiceUtil.onErrorHandler
		);
};
