function PuppetryLiveProtocolUI() {
	this._header = 'Live-Protokoll';
	this._singletonUI = null;	
	this._interval = null;
	this._intervalDuration = 2;
	this._scrollLock = true;
	this._refreshing = false;
	
	var self = this;
	
	this._replaceToolbarItem = function(itemId, iconId, title) {
		var toolbar = self._singletonUI.find('.jsPanel-hdr-r');
		toolbar.find(itemId).find('span')
			.removeClass()
			.addClass('ic')
			.addClass(iconId)
			.addClass('sz-15')
			.removeAttr('style')
			.css('display', 'block')
			.attr('data-grunticon-embed', '')
			.attr('title', title);
	};
};

PuppetryLiveProtocolUI.prototype.initUI = function() {
	
};

PuppetryLiveProtocolUI.prototype.showUI = function() {
	var self = this;
	
	if (this._singletonUI) {
	    this._singletonUI.close();
	}
	
	var pwidth = 800; 
	var pheight = 300; 
	
	var ptop = $(window).height() > 75 ? 75 : 0; 
	var pleft = 0; 
	
	this._singletonUI = $.jsPanel({
		title: this._header, 
		theme: 'puppetry',
		overflow: 'scroll',
		draggable: {
	        containment: "window",
	    },
		size: { width: pwidth, height: pheight },
		position: 'top center',
		offset: { top: 75, left: 50 }, 
	});
	this._singletonUI.attr("prev-width", pwidth);
	this._singletonUI.attr("prev-height", pheight);
	
	if($('#wrapper').hasClass('admin-mode')) {
		this._singletonUI.addClass('admin-mode');
	}
	else {
		this._singletonUI.addClass('live-mode');
	}
	
	var filter = '';
	filter += '<div class="log-entry-filter">';
	filter += '   <div class="left">';
	filter += '      <label><input type="checkbox" name="type" value="event" checked="checked">Ereignisse</label>';
	filter += '      <label><input type="checkbox" name="type" value="call" checked="checked">Aufrufe</label>';
	filter += '      <label><input type="checkbox" name="type" value="error" checked="checked">Fehler</label>';
	filter += '      <label><input type="checkbox" name="type" value="hint" checked="checked">Hinweise</label>';
	filter += '   </div>';
	filter += '   <div class="right">';
	filter += '      <label>Filter: <input type="text" name="message" value=""></label>';
	filter += '   </div>';
	filter += '</div>';
	this._singletonUI.find('.jsPanel-content').before(filter);
	
	this._singletonUI.find('.log-entry-filter').on('input change propertychange paste keyup', function() {
		self.refreshUI();
	});
	
	this._singletonUI.on('jspanelstatechange', function(param) {
		self.updateScrollLockState();
	});
	
	this._singletonUI.on('resizestop', function(param) {
		self.updateScrollLockState();
	});
		
	$('body').on('jspanelclosed', function closeHandler(event, id) {
		clearInterval(self._interval);
		self._interval = null;
		self._singletonUI = null;
		// close handlers attached to body should be removed again
        $('body').off('jspanelclosed', closeHandler);
	});
	
	this._singletonUI.find('.jsPanel-hdr-r').append('<div class="jsPanel-btn-lock" style="background-image: none;"><span></span></div>');		
	this._singletonUI.find('.jsPanel-hdr-r').find('.jsPanel-btn-lock').on('click', function() {
		self.toggleScrollLock();
	});
	this._singletonUI.find('.jsPanel-hdr-r').append('<div class="jsPanel-btn-unlock" style="background-image: none; display: none"><span></span></div>');
	this._singletonUI.find('.jsPanel-hdr-r').find('.jsPanel-btn-unlock').on('click', function() {
		self.toggleScrollLock();
	});
	
	this._replaceToolbarItem('.jsPanel-btn-lock', 'ic-nav-lock-closed', 'Automatisches Scrollen ausschalten');
	this._replaceToolbarItem('.jsPanel-btn-unlock', 'ic-nav-lock-open', 'Automatisches Scrollen einschalten');
	this._replaceToolbarItem('.jsPanel-btn-max', 'ic-nav-win-max', 'Maximieren');
	this._replaceToolbarItem('.jsPanel-btn-min', 'ic-nav-win-min', 'Minimieren');
	this._replaceToolbarItem('.jsPanel-btn-close', 'ic-nav-close', 'Schließen');
	this._replaceToolbarItem('.jsPanel-btn-norm', 'ic-nav-win-restore', 'Wiederherstellen');
	this._replaceToolbarItem('.jsPanel-btn-small', 'ic-nav-win-title', 'Zusammenklappen');
	this._replaceToolbarItem('.jsPanel-btn-smallrev', 'ic-nav-win-title-restore', 'Ausklappen');	
	
	$('html').removeClass('grunticon');
	$.getScript("thirdparty/icomb/icomb.loader.js", function() {});

	this.refreshUI();
	
	PuppetryConnectorService.getConnector(
			function(data, textStatus, jqXHR){
				if (self._intervalDuration !== data.liveProtocolInterval) {
					self._intervalDuration = data.liveProtocolInterval;
					if (self._interval) {
						clearInterval(self._interval);
						self._interval = null;
					}
				}
			
				if (self._intervalDuration > 0 && !self._interval && self._singletonUI) {
					self._interval = setInterval(function() {
						self.refreshUI();
					}, self._intervalDuration * 1000); 
				}
			},
			EHexServiceUtil.onErrorHandler,
			this
		);
	
	Puppetry.adjustContent();
};

PuppetryLiveProtocolUI.prototype.toggleScrollLock = function() {
	this._scrollLock = !(this._scrollLock === true);
	this.updateScrollLockState();
}

PuppetryLiveProtocolUI.prototype.updateScrollLockState = function() {
	if (this._scrollLock === true) {
		this._singletonUI.find('.jsPanel-hdr-r').find('.jsPanel-btn-lock').css('display', '');
		this._singletonUI.find('.jsPanel-hdr-r').find('.jsPanel-btn-unlock').css('display', 'none');
	} else {
		this._singletonUI.find('.jsPanel-hdr-r').find('.jsPanel-btn-lock').css('display', 'none');
		this._singletonUI.find('.jsPanel-hdr-r').find('.jsPanel-btn-unlock').css('display', '');
	}
	var panelHeight = this._singletonUI.outerHeight();
	var headerHeight = this._singletonUI.find('.jsPanel-hdr').outerHeight();
	var footerHeight = this._singletonUI.find('.jsPanel-ftr:visible').outerHeight();
	var filterHeight = this._singletonUI.find('.log-entry-filter').outerHeight();
	this._singletonUI.find('.jsPanel-content').css('height', panelHeight - headerHeight - footerHeight - filterHeight);
}

PuppetryLiveProtocolUI.prototype.refreshUI = function() {
	var self = this;
	
	if (self._refreshing === true) {
		return;
	}
	
	self._refreshing = true;
	
	PuppetryLogService.getLiveInterfaceLog(
		function(data, textStatus, jqXHR) {
			var ui = self._singletonUI;
			if (!ui) {
				self._refreshing = false;
				return;
			}
			
			var updated = false;
			
			if (data != null && !$.isEmptyObject(data)) {
				$('.log-entry').each(function(key, item) {
					var result = $.grep(data, function(e){ 
						return e.uuid == item.id; 
					});
					if (result.length == 0) {
						item.remove();
						updated = true;
					}
				});
				
				$.each(data, function(key, item) {
					if (!$('[id="' + item.uuid + '"].log-entry').length) {							
						var itemHtml = self.renderLogEntry(item);							
						ui.content.append(itemHtml);
						updated = true;
					}
					
					var passedFilter = self.filterLogEntry(item);
					if (passedFilter === true) {
						$('[id="' + item.uuid + '"].log-entry').show();
					} else {
						$('[id="' + item.uuid + '"].log-entry').hide();
					}
				});
			} else {
				ui.content.empty();
			}
					
			if (self._scrollLock === true && updated === true && ui.content.find('div:last').length > 0) {						
				ui.content.scrollTop(ui.content.find('div:last').offset().top - ui.content.offset().top + ui.content.scrollTop());	
			}
			
			self._refreshing = false;
		},
		function(jqXHR, textStatus, errorThrown) {
			self._refreshing = false;
			clearInterval(self._interval);
			EHexServiceUtil.onErrorHandler(jqXHR, textStatus, errorThrown);
		}
	);
};

PuppetryLiveProtocolUI.prototype.filterLogEntry = function(item) {
	var ok = true;
	switch (item.type) {
	case 'EVENT':
	case 'EVENT_SUPPRESSED':
		if (!$('.log-entry-filter').find('input[name="type"][value="event"]').prop('checked')) {
			ok = false;
		}
		break;
	case 'ERROR':
		if (!$('.log-entry-filter').find('input[name="type"][value="error"]').prop('checked')) {
			ok = false;
		}
		break;
	case 'CALL_REQUEST':
	case 'CALL_RESPONSE':
	case 'CALL_SDS':
		if (!$('.log-entry-filter').find('input[name="type"][value="call"]').prop('checked')) {
			ok = false;
		}						
		break;
	case 'TESTCASE':
		if (!$('.log-entry-filter').find('input[name="type"][value="hint"]').prop('checked')) {
			ok = false;
		}
		break;
	default:
		break;
	}
	
	var filterText = $('.log-entry-filter').find('input[name="message"]').val();
	if (filterText && filterText != '') {
		var expr = new RegExp(filterText, 'i');
		if (!item.message.match(expr) && !new Date(item.date).toLocaleTimeString().match(expr)) {
			ok = false;
		}
	}

	return ok;
};

PuppetryLiveProtocolUI.prototype.renderLogEntry = function(item) {
	var icon;
	var title;
	var detail;
	switch (item.type) {
	case 'EVENT':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><polygon points="56,36 42,36 50,8 24,43 38,43 30,72 "></polygon></svg>';
		title = 'Ereignis';
		break;
	case 'EVENT_SUPPRESSED':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><g><path d="M40,4c19.9,0,36,16.1,36,36S59.9,76,40,76S4,59.9,4,40S20.1,4,40,4 M40,0C17.9,0,0,17.9,0,40s17.9,40,40,40s40-17.9,40-40S62.1,0,40,0L40,0z"/></g><g><rect x="19" y="11.1" transform="matrix(0.7071 -0.7071 0.7071 0.7071 -8.6985 21)" width="4" height="19.8"/></g><polygon points="58,35 42,35 50,8 22,44 38,44 30,72 "/><g><rect x="57.4" y="49.1" transform="matrix(0.7094 -0.7048 0.7048 0.7094 -24.9211 59.2564)" width="4" height="21.6"/></g></svg>';
		title = 'Ereignis';
		break;							
	case 'ERROR':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><polygon points="69.4,13.4 66.6,10.6 40,37.2 13.4,10.6 10.6,13.4 37.2,40 10.6,66.6 13.4,69.4 40,42.8 66.6,69.4 69.4,66.6  42.8,40 "></polygon></svg>';
		title = 'Fehler';
		detail = '../log/interface/live/' + item.rid + '/response';
		break;
	case 'CALL_REQUEST':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><g><polygon points="14,72 70,40 14,8 	"/></g></svg>';
		title = 'Anfrage';
		detail = '../log/interface/live/' + item.rid + '/request';
		break;
	case 'CALL_RESPONSE':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><g><path d="M62,65.1L18.1,40L62,14.9V65.1 M66,72V8L10,40L66,72L66,72z"/></g></svg>';
		title = 'Antwort';
		detail = '../log/interface/live/' + item.rid + '/response';
		break;
	case 'CALL_SDS':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><polyline points="69.2,72 46.2,49 49,46.2 72,69.2 "></polyline><path d="M32,12c11,0,20,9,20,20s-9,20-20,20s-20-9-20-20S21,12,32,12 M32,8C18.7,8,8,18.7,8,32s10.7,24,24,24s24-10.7,24-24 S45.3,8,32,8L32,8z"></path></svg>';
		title = 'Dienstverzeichnisdienst';
		break;
	case 'TESTCASE':
		icon = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 80 80" style="enable-background:new 0 0 80 80;" xml:space="preserve"><g> <path d="M28,64v4h-4v-4H28 M32,60H20v12h12V60L32,60z"></path></g><rect x="36" y="20" width="24" height="4"></rect><rect x="36" y="28" width="20" height="4"></rect><rect x="36" y="40" width="24" height="4"></rect><rect x="36" y="48" width="16" height="4"></rect><rect x="36" y="60" width="24" height="4"></rect><rect x="36" y="68" width="20" height="4"></rect><path d="M46,6c0-3.3-2.7-6-6-6s-6,2.7-6,6h-6v8h24V6H46z M40,4c1.1,0,2,0.9,2,2c0,0.1,0,0.3,0,0.4c-0.1,0.7-0.6,1.2-1.2,1.4 C40.5,7.9,40.3,8,40,8s-0.5-0.1-0.8-0.2c-0.6-0.3-1-0.8-1.2-1.4c0-0.1,0-0.3,0-0.4C38,4.9,38.9,4,40,4z"></path><polygon points="56,6 56,10 64,10 64,76 16,76 16,10 24,10 24,6 12,6 12,80 68,80 68,6 "></polygon><g> <rect x="24" y="20.3" transform="matrix(0.7071 -0.7071 0.7071 0.7071 -10.7696 26)" width="4" height="11.3"></rect></g><g> <rect x="20.3" y="24" transform="matrix(0.7071 -0.7071 0.7071 0.7071 -10.7696 26)" width="11.3" height="4"></rect></g><g> <polygon points="26.9,51.7 21.1,48.8 22.9,45.2 25.1,46.3 28.2,40.1 31.8,41.9  "></polygon></g></svg>';
		title = 'Testfall';
		break;
	default:
		icon = '';
	    title = '';
		break;
	}
	
	var html = '';
	html += '<div class="log-entry ' + item.type + ' left" id="' + item.uuid + '">'; 
	html += '  <div class="left pd-0-10-0-0" title="Zeitpunkt">' + new Date(item.date).toLocaleTimeString() + '</div>';
	html += '  <div class="left pd-0-20-0-0 log-entry-type" title="' + title + '">' + icon + '</div>';
	
	if (detail) {
		html += '  <div style="display: flex;" title="Meldung"><a href="' + detail + '" target="_blank">' + item.message + '</a></div>';
	} else {
		html += '  <div style="display: flex;" title="Meldung">' + item.message + '</div>';
	}
	
	html += '</div>';
	
	return html;
};