function PuppetryLiveTestCaseUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	var self = this;
	
	this._converter = new showdown.Converter(),
	
	this._header = 'Testlabor';
	this._contentId = '.live-testcase-content';
	this._listViewId = '.live-testcase-list';
	this._detailViewId = '.live-testcase-detail';
	this._entryId = '.live-testcase';
	this._entryTemplateId = '#live-testcase-template';
	this._sortBy = 'label';
	this._menuItemId = '.live-testcase';
	
	this._setId = null;
	
	this._listEntryHandler = function(success, error, context) {
		PuppetryTestCaseService.getTestCases(this._setId, success, error, context);
	};

	this._getEntryHandler = function(id, success, error, context) {
		PuppetryTestCaseService.getTestCase(this._setId, id, success, error, context);
	};
	
	this._validationResultRenderer = function(stepData, stepPage) {
		if (stepData.validation && stepData.validationResultList){
			
			if (stepPage.find('.wizard-step-validation').length === 0) {
				var wizardStepValidation = $('#wizard-step-validation-template').clone(true);
				wizardStepValidation.removeAttr('id');
				wizardStepValidation.show();
				stepPage.find('.row:first').append(wizardStepValidation);	
			}
			
			var iconOK = $('#ic-nav-confirm').html();
			var iconNOK = $('#ic-nav-close').html();
			
			
			stepPage.find('.validation-label').hide();
			
			if (stepData.validationResultList.length > 0) {
				stepPage.find('.validation-label').show();
				stepPage.find('.server-validation').show();
				
				var success = true;
				stepPage.find('.server-validation-result .validation').remove();
				$.each(stepData.validationResultList, function(key, value) {
					success = success & value.success;
					var validationClass = value.success ? 'validation-ok' : 'validation-nok';
					stepPage.find('.server-validation-result').append('<div class="row pd-5-20 validation"><div class="col-md-11 pd-9-10 ' + validationClass + '">' + value.message + '</div><div class="col-md-1 ic-2x right ' + validationClass + '">' + (value.success ? iconOK : iconNOK) + '</div></div>');					
				});		
				
				if(stepData.validation.retryAllowed && !success) {
					stepPage.find('.server-validation-retry').show();
				}
				else {
					stepPage.find('.server-validation-retry').hide();
				}
				
			}
			else {
				stepPage.find('.server-validation').hide();
				stepPage.find('.server-validation-retry').hide();
			}
			
			if(stepData.validation.userValidation) {
				stepPage.find('.validation-label').show();
				
				stepPage.find('input[type="checkbox"].client-validation').change(function() {	
					stepPage.find('.client-validation-result').empty();
					stepPage.find('.client-validation-result').append($(this).is(':checked') ? iconOK : iconNOK);
					
					if ($(this).is(':checked')) {
						stepPage.find('.client-validation .validation').removeClass('validation-nok').addClass('validation-ok');
					} else {
						stepPage.find('.client-validation .validation').removeClass('validation-ok').addClass('validation-nok');
					}					
				});
				
				stepPage.find('.client-validation').show();
			}
			else {
				stepPage.find('.client-validation').hide();
			}
			
			
			if(stepData.validation.commentAllowed || stepData.validation.commentRequired) {
				stepPage.find('.user-comment-label').text(stepData.validation.commentLabel);
				stepPage.find('.user-comment').attr("requiredComment", stepData.validation.commentRequired);
				stepPage.find('.user-comment').show();
			}
			else {
				stepPage.find('.user-comment').hide();
				stepPage.find('.user-comment').attr('requiredComment', 'false');
			}
			
			if(stepData.validation.uploadAllowed || stepData.validation.uploadsRequired > 0) {
				stepPage.find('.user-uploads-label').text(stepData.validation.uploadLabel);
				stepPage.find('.user-uploads').attr("requiredUploads", stepData.validation.uploadsRequired);
				stepPage.find('.user-uploads').show();
				
				self.initUpload(stepPage, stepData.testCaseId, stepData.index);
			}
			else {
				stepPage.find('.user-uploads').hide();
				stepPage.find('.user-uploads').attr('requiredUploads', -1);
			}
			
			stepPage.find('.validation').show();				
		}
	};
};

// Create the prototype
PuppetryLiveTestCaseUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetryLiveTestCaseUI.prototype.constructor = PuppetryLiveTestCaseUI;

PuppetryLiveTestCaseUI.prototype.initUI = function() {
	AbstractDataListUI.prototype.initUI.call(this);
};

PuppetryLiveTestCaseUI.prototype.showUI = function(source, detail) {
	
		if (source) {
			var testSet = $(source).closest('.live-testcase-set');
			this._setId = testSet.attr('id');
			isProtected = testSet.attr('protected');

			if (this._setId == null || this._setId == undefined) {
				Puppetry.showLiveTestCaseSetUI();
			}
			
			$('.live-mode > .header').html('<span class="font-20"><a href="#" onclick="Puppetry.showLiveTestCaseSetUI();">' + this._header + '</a> &lt; </span><span class="font-50"><a href="#" onclick="Puppetry.currentController().showUI();">' + this._setId + '</a>');
			
			var reportItem = $('#report-toolbar-template').clone(true);
			reportItem.removeAttr('id');
			$('.live-mode > .toolbar-container').empty();
			$('.live-mode > .toolbar-container').append(reportItem);
			
			if(isProtected != "true") {
				$('.live-mode > .toolbar-container .testcase-set-zip-gematik').hide();
			}
		}
		
		if ($('#wrapper').hasClass('admin-mode')) {
			$('#wrapper').removeClass('admin-mode').addClass('live-mode');
			$('.admin-mode').hide();
		}
		$('.live-content').hide();
		$(this._contentId).show();
		
		AbstractDataListUI.prototype.showUI.call(this, source, detail);
	
};


PuppetryLiveTestCaseUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.label);
	var description = (model.optional ? "Optional: " : "")+model.shortDescription;
	viewElement.attr('description', description);

	if(model.optional) {
		viewElement.addClass("optional");
	}
	
	viewElement.find('.badge-state').addClass('off');
	if(model.lastRun == undefined) {
		viewElement.addClass("disabled");
	}
	
	if(model.unsupported) {
		viewElement.find('.badge-state.testresult-unsuported').removeClass('off');
		viewElement.find('.testcase-start').addClass('disabled');
	}
	else if(model.lastRun != undefined) {
		if(!model.lastResult) {
			viewElement.addClass("warning");
			viewElement.find('.badge-state.testresult-error').removeClass('off');
		}
		else {
			viewElement.find('.badge-state.testresult-success').removeClass('off');
		}
	}

	viewElement.find('.protected').addClass(model['protected'] === true ? 'protected-on' : 'protected-off');
	
	viewElement.find('.testcase-name').text(model.name);
	viewElement.find('.testcase-shortDescription').text(description);
	
	viewElement.find('.test-case-log').css('display', model.hasLog === true ? 'block' : 'none');
	viewElement.find('.test-case-report').css('display', model.hasReport === true ? 'block' : 'none');
};

PuppetryLiveTestCaseUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	if (model.id != null && model.id != '') {
		detailView.attr('testcase-id', model.id);				
	} else {
		detailView.removeAttr('testcase-id');
	}
	
	if (model.name != null && model.name != '') {
		detailView.attr('label', model.name);
	} else {
		detailView.removeAttr('label');
	}
	
	if(model.optional) {
		detailView.addClass("optional");
	}
	else {
		detailView.removeClass("optional");
	}
	
	detailView.find('.testcase-name').val(model.name);
	detailView.find('.testcase-shortDescription').val((model.optional ? "Optional: " : "")+model.shortDescription);
	detailView.find('.testcase-description').val(model.description);
	
	detailView.find('.testcase-unsupported input[type="checkbox"]').prop('checked', model.unsupported != null ? model.unsupported : false);
	if(model.unsupported) {
		detailView.find('.testcase-start').addClass('disabled');
	}

	if(model.lastRun != undefined) {
		var date = new Date(model.lastRun);
		detailView.find('.testcase-run-datetime').text(date.toLocaleDateString() + ' ' + date.toLocaleTimeString());
		detailView.find('.testcase-run-info').show();
	}
	else {
		detailView.find('.testcase-run-info').hide();
	}
	
	
	var stepList = detailView.find('.step-list');
	stepList.empty();
	$.each(model.steps, function( index, value ) {
		stepList.append('<li class="font-25 mg-0-15-15-0">'+value.shortDescription+'</li>');
	});
};

PuppetryLiveTestCaseUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	model.id = viewElement.attr('testcase-id');
	model.label = viewElement.attr('label');
	
	return validationResult;
};

PuppetryLiveTestCaseUI.prototype.showBasicUI = function(source) {
	$('.testcase-detail-basic').css('display', 'block');
	$('.testcase-detail-steps').css('display', 'none');	
	$('.testcase-detail-reset').css('display', 'none');	
};

PuppetryLiveTestCaseUI.prototype.showStepsUI = function(source) {
	$('.testcase-detail-basic').css('display', 'none');
	$('.testcase-detail-steps').css('display', 'block');
	$('.testcase-detail-reset').css('display', 'none');
};

PuppetryLiveTestCaseUI.prototype.showResetUI = function(source) {
	$('.testcase-detail-basic').css('display', 'none');
	$('.testcase-detail-steps').css('display', 'none');
	$('.testcase-detail-reset').css('display', 'block');
};

PuppetryLiveTestCaseUI.prototype.resetTestCase = function(source) {
	var self = this;
	
	var caseId;
	
	if (source) {
		var testCaseElmt = $(source).closest('.live-testcase');
		caseId = testCaseElmt.attr('id');
	} else {
		caseId = $(this._detailViewId).attr('testcase-id');
	}

	if (caseId) {
		EHexDialogUI.showWait('Daten werden zurückgesetzt...');
		
		PuppetryTestCaseService.resetTestcase(
				self._setId,
				caseId,
				function(data, textStatus, jqXHR) {
					var detailView =  $(self._detailViewId);
					self.toDetailView(data, detailView);
					
					var listViewElement = $('.live-testcase#' + caseId);
					listViewElement.removeClass("warning").addClass("disabled");
					listViewElement.find('.badge-state.testresult-unsuported').addClass('off');
					listViewElement.find('.badge-state.testresult-error').addClass('off');
					listViewElement.find('.badge-state.testresult-success').addClass('off');
					
					listViewElement.find('.test-case-log').css('display', 'none');
					listViewElement.find('.test-case-report').css('display', 'none');
					
					setTimeout(EHexDialogUI.hideWait, 250);
				}, 
				EHexServiceUtil.onErrorHandler,
				this
		);	
	}
};

PuppetryLiveTestCaseUI.prototype.toggleUnsupported = function(source) {
	var self = this;
	var detailView = $(self._detailViewId);
	var testCaseId = detailView.attr('testcase-id');
	
	var checked = detailView.find('.testcase-unsupported input[type="checkbox"]').is(':checked');
	if(checked) {
		detailView.find('.testcase-start').addClass('disabled');
	}
	else {
		detailView.find('.testcase-start').removeClass('disabled');
	}
	
	PuppetryTestCaseService.setUnsupported(
			self._setId,
			testCaseId, 
			checked,
			function(data, textStatus, jqXHR) {
				var listViewElement = $('#' + testCaseId);
				listViewElement.find('.badge-state').addClass('off');
				listViewElement.find('.testcase-start').removeClass('warning');
				if(checked) {
					listViewElement.find('.badge-state.testresult-unsuported').removeClass('off');
					listViewElement.find('.testcase-start').addClass('disabled');
				}
				else {
					listViewElement.find('.testcase-start').removeClass('disabled');
				}
				self._dirty=false;
			}, 
			EHexServiceUtil.onErrorHandler,
			this
	);	
};

PuppetryLiveTestCaseUI.prototype.startTestCase = function(source) {
	var self = this;

	var testCaseId;
	var testCaseName;
	
	if (source) {
		if($(source).closest('.testcase-start').hasClass('disabled')) {
			return;
		}

		var testCaseElmt = $(source).closest('.live-testcase');
		testCaseId = testCaseElmt.attr('id');
		testCaseName = testCaseElmt.attr('label');
	} else {
		if($(this._detailViewId).find('.testcase-start').hasClass('disabled')) {
			return;
		}
		
		testCaseId = $(this._detailViewId).attr('testcase-id');
		testCaseName = $(this._detailViewId).attr('label');
	}

	if (testCaseId) {
		EHexDialogUI.showWait('Testfall ' + '„' + testCaseName + '“' + ' wird gestartet...');
		PuppetryTestCaseService.startTestCase(
				self._setId,
				testCaseId, 
				function(data, textStatus, jqXHR) {
					EHexDialogUI.hideWait();				
					self.showWizard(data);
				}, 
				EHexServiceUtil.onErrorHandler,
				this
		);	
	}
};

PuppetryLiveTestCaseUI.prototype.showWizard = function(wizardData) {
	var self = this;
	
	if (!PuppetryWizardUI.isActive() || wizardData.currentStepIndex != PuppetryWizardUI.currentStep()) { 
		if(wizardData.currentStepIndex != PuppetryWizardUI.currentStep()) {
			PuppetryWizardUI.hideWizard();
		}
		if(self._setId == null) {
			self._setId = wizardData.setId;
			
			$('.live-mode > .header').html('<span class="font-20"><a href="#" onclick="Puppetry.showLiveTestCaseSetUI();">' + self._header + '</a> &lt; </span><span class="font-50"><a href="#" onclick="Puppetry.currentController().showUI();">' + self._setId + '</a>');
		}
		
		var onNextHandler = function(tab, navigation, index) {
			var page = $('#wizardDialog .tab-content .tab-pane[id="tab' + index + '"]');
			var hasValidation = page.find('.validation:visible').length > 0;
			if (hasValidation) {
				
				var validationResult = {};
				validationResult.success = page.find('.client-validation:visible').length == 0 || page.find('div.client-validation input[type="checkbox"].client-validation').prop('checked');
				if(page.find('.client-validation:visible').length > 0) {
					validationResult.message = validationResult.success ? 'Die Aktion wurde aus Sicht des Primärsystems erfolgreich abgeschlossen.' : 'Die Aktion konnte aus Sicht des Primärsystems nicht erfolgreich abgeschlossen werden.';
				}
				validationResult.comment = page.find('div.user-comment textarea.client-validation-message').val();	
				
				var tabDropzone = page.find('.upload-data')[0].dropzone;
				var files = tabDropzone ? tabDropzone.getFilesWithStatus(Dropzone.ADDED) :  undefined;
				
				var isCommentRequired = page.find('.user-comment').attr("requiredComment");
				var requiredUploads = parseInt(page.find('.user-uploads').attr("requiredUploads"));
				
				if(isCommentRequired == 'true' && (!validationResult.comment || validationResult.comment.trim().length == 0)) {					
					EHexAlertUI.showError("Es muss ein Kommentar eingegeben werden!");
					return;
				}

				if(requiredUploads > 0 && (!files || files.length < requiredUploads)) {
					if(requiredUploads < 2) {
						EHexAlertUI.showError('Es muss mindestens eine Datei zur Dokumentation hochgeladen werden!');
					}
					else {
						EHexAlertUI.showError('Es müssen mindestens ' + requiredUploads + ' Dateien zur Dokumentation hochgeladen werden!');
					}
					return;
				}
				
				var commentTestCaseStep =  function() {
					PuppetryTestCaseService.commentTestCaseStep(
							validationResult,
							function(data, textStatus, jqXHR) {
								PuppetryTestCaseService.nextTestCaseStep(
										function(data, textStatus, jqXHR) {
											PuppetryWizardUI.showNext(index);			
										}, 
										EHexServiceUtil.onErrorHandler,
										self);
							}, 
							EHexServiceUtil.onErrorHandler,
							self);	
				}

				if (files && files.length > 0) {
					var uploadErrorsOccurred = false;
					tabDropzone.on("error", function(file, errorMessage, xhr) {
						uploadErrorsOccurred = true;
						console.log("error: " + file + " - "+ errorMessage);
						EHexAlertUI.showError(errorMessage);
					});
					tabDropzone.on("queuecomplete", function() {
						PuppetryWizardUI.hideWait();
						
						if (!uploadErrorsOccurred) {
							commentTestCaseStep();
						}
						else {
							tabDropzone.removeAllFiles(true);
						}
					});
					
					PuppetryWizardUI.showWait(tab.text() + ' - Daten werden hochgeladen...');
					setTimeout(function() { tabDropzone.enqueueFiles(files); }, 500);
				}
				else {
					commentTestCaseStep();
				}
				
			} else {
				PuppetryWizardUI.showWait(tab.text() + ' wird ausgeführt...');
				setTimeout(function() {
					PuppetryTestCaseService.executeTestCaseStep(
							function(data, textStatus, jqXHR) {
								PuppetryWizardUI.hideWait();
								
								var step = data.currentStep;
								step.testCaseId = data.id;
								if (step.validation) {
									var page = $('#wizardDialog .tab-content .tab-pane[id="tab' + index + '"]');
									self._validationResultRenderer(step, page);
								} else {
									PuppetryTestCaseService.nextTestCaseStep(
											function(data, textStatus, jqXHR) {
												PuppetryWizardUI.showNext(index);			
											}, 
											EHexServiceUtil.onErrorHandler,
											this);
								}
							}, 
							EHexServiceUtil.onErrorHandler,
							this
					);
				}, 500);	
			}
		};
		
		for (var i = 0; i < wizardData.steps.length; i++) {
			var step = wizardData.steps[i];
						
			step.onNext = onNextHandler;
			/*step.onTabChange = function(tab, navigation, index, nextTab) {
				console.log('onTabChange');
			};*/
	
			if (step.combine) {
				step.data = step.combine;
				step.page = $('#wizard-step-info-template').clone(true);
			} else  if (step.connectTerminal) {
				step.data = step.connectTerminal;
				step.page = $('#wizard-step-connect-terminal-template').clone(true);
			} else if (step.insertCard) {
				step.data = step.insertCard;
				step.page = $('#wizard-step-insert-card-template').clone(true);
			} else if (step.ejectCard) {
				step.data = step.ejectCard;
				step.page = $('#wizard-step-eject-card-template').clone(true);
			} else if (step.fireEvent) {
				step.data = step.fireEvent;
				step.page = $('#wizard-step-fire-event-template').clone(true);
			} else if (step.raiseServiceHook) {
				step.data = step.raiseServiceHook;
				step.page = $('#wizard-step-raise-service-hook-template').clone(true);
			} else if (step.info) {
				step.data = step.info;
				step.page = $('#wizard-step-info-template').clone(true);
			} else if (step.updateAuthenticationMechanism) {
				step.data = step.updateAuthenticationMechanism;
				step.page = $('#wizard-step-update-auth-method-template').clone(true);
			} else if (step.updateOnStatus) {
				step.data = step.updateOnStatus;
				step.page = $('#wizard-step-update-on-status-template').clone(true);
			} else if (step.updateOnlineStatus) {
				step.data = step.updateOnlineStatus;
				step.page = $('#wizard-step-update-online-status-template').clone(true);
			} else if (step.suppressEvents) {
				step.data = step.suppressEvents;
				step.page = $('#wizard-step-suppress-events-template').clone(true);
			} else if (step.updateSdsStatus) {
				step.data = step.updateSdsStatus;
				step.page = $('#wizard-step-update-sds-status-template').clone(true);
			} else if (step.uploadData) {
				step.data = step.uploadData;
				step.page = $('#wizard-step-upload-data-template').clone(true);
				
				if (self.initUpload(step.page, wizardData.id, i)) {				
				
					step.onNext = function(tab, navigation, index) {
						var uploadStep = wizardData.steps[index-1];
						
						var tabContentId = $('a', tab).attr('href');
						var tabDropzone = $(tabContentId).find('.upload-data')[0].dropzone;
						
						var files = tabDropzone ? tabDropzone.getFilesWithStatus(Dropzone.ADDED) :  undefined;
						if(uploadStep.data.uploadsRequired > 0 && (!files || files.length < uploadStep.data.uploadsRequired)) {
							if(uploadStep.data.uploadsRequired < 2) {
								EHexAlertUI.showError('Es muss mindestens eine Datei zur Dokumentation hochgeladen werden!');
							}
							else {
								EHexAlertUI.showError('Es müssen mindestens ' + uploadStep.data.uploadsRequired + ' Dateien zur Dokumentation hochgeladen werden!');
							}
							return;
						}
						
						if (files && files.length > 0) {
							var uploadErrorsOccurred = false;
							tabDropzone.on("error", function(file, errorMessage, xhr) {
								uploadErrorsOccurred = true;
								console.log("error: " + file + " - "+ errorMessage);
								EHexAlertUI.showError(errorMessage);
							});
							tabDropzone.on("queuecomplete", function() {
								PuppetryWizardUI.hideWait();
								
								if (!uploadErrorsOccurred) {
									onNextHandler(tab, navigation, index);
								}
								else {
									tabDropzone.removeAllFiles(true);
								}
							});
							
							PuppetryWizardUI.showWait(tab.text() + ' - Daten werden hochgeladen...');
							setTimeout(function() { tabDropzone.enqueueFiles(files); }, 500);
						}
						else {
							onNextHandler(tab, navigation, index);
						}
					};
				}
			} 
			
			step.page.removeAttr('id');
			step.page.css('display', 'block');
			
			step.data.testCaseId = wizardData.id;
			step.data.index = i;
			self._validationResultRenderer(step.data, step.page);
			
			
		    var descriptionHTML = step.data.description ? self._converter.makeHtml(step.data.description) : "";
		    var noteHTML = step.data.note ? self._converter.makeHtml(step.data.note) : "";
			
			step.page.find('.description').html(descriptionHTML);
			step.page.find('.note').html(noteHTML);
			step.page.find('.client-name').val(step.data.client ? step.data.client.label : '');
			if(step.data.client) {
				step.page.find('.client-name-help').attr('data-original-title', 'Mandanten ID: '+step.data.client.principalId+'\n' + 'Clientsystem ID: '+step.data.client.clientSystemId+'\n' + 'Arbeitsplatz ID: '+step.data.client.workplaceId+'\n');
			}
			else {
				step.page.find('.client-info').hide();
			}
			step.page.find('.terminal-name').val(step.data.terminal ? step.data.terminal.name : '');
			step.page.find('.card-name').val(step.data.card ? step.data.card.label : '');
			if(step.data.card) {
				var cardDescription = step.data.card.description;
				if(step.data.card.data) {
					cardDescription += '\n' + step.data.card.data.givenName + ' ' + step.data.card.data.surname;
					if(step.data.card.data.dateOfBirth) {
						cardDescription += '\n' + $.datepicker.formatDate('dd.mm.yy', new Date(step.data.card.data.dateOfBirth));
					}
					cardDescription += '\n' + step.data.card.data.insuredId;
				}
				step.page.find('.card-name-help').attr('data-original-title', cardDescription);
			}
			step.page.find('.event-name').val(step.data.topic ? step.data.topic : '');

			if(step.data.serviceHook && !step.data.serviceHook.active) {
				step.page.find('.servicehook-details').hide();
			}
			step.page.find('.method-name').val(step.data.serviceHook ? step.data.serviceHook.serviceMethod : '');
			step.page.find('.servicehook-error-name').val(step.data.serviceHook ? step.data.serviceHook.serviceError : '');
			step.page.find('.servicehook-interception-name').val(step.data.serviceHook ? step.data.serviceHook.interception : '');
			step.page.find('.servicehook-delay-before').val(step.data.serviceHook ? step.data.serviceHook.delayBefore : '');
			step.page.find('.servicehook-delay-after').val(step.data.serviceHook ? step.data.serviceHook.delayAfter : '');
			
			var authMech = self.getAuthMechName(step.data.authenticationMechanism);
			step.page.find('.auth-method-name').val(authMech);
			var cetpAuthMech = self.getAuthMechName(step.data.cetpAuthenticationMechanism);
			step.page.find('.cetp-auth-method-name').val(cetpAuthMech);
			step.page.find('.open-service-channel').val(step.data.serviceOpen === true ? 'Aktiviert' : 'Deaktiviert');
			
			
			step.page.find('.on-status').val(step.data.on === true ? 'Eingeschaltet' : 'Ausgeschaltet');
			step.page.find('.online-status').val(step.data.online === true ? 'Online' : 'Offline');
			step.page.find('.suppress-events').val(step.data.suppressEvents === true ? 'Unterdrückt' : 'Zugelassen');
			step.page.find('.connection-state').val(step.data.state === true ? 'Verbunden' : 'Getrennt');
			
			var sdsStatus = self.getSDSStatusName(step.data.sdsStatus);
			step.page.find('.sds-status').val(sdsStatus);
			
			step.page.find('.status').tooltip();
		}	
		
		var completeStep = {};
		completeStep.data = {};
		completeStep.data.shortDescription = 'Fertigstellen';
		completeStep.page = $('#wizard-step-complete-template').clone(true);
		completeStep.page.removeAttr('id');
		completeStep.page.css('display', 'block');
		wizardData.steps.push(completeStep);
		
		var summaryStep = {};		
		summaryStep.data = {};
		summaryStep.data.shortDescription = 'Zusammenfassung';
		summaryStep.page = $('#wizard-step-summary-template').clone(true);
		summaryStep.page.removeAttr('id');
		summaryStep.page.find('a.technical-protocol').click(function(source) {
			PuppetryTestCaseService.getTestCaseLog(
					self._setId,
					wizardData.id,
					function(data, textStatus, jqXHR) {},
					EHexServiceUtil.onErrorHandler
			);
		});
		summaryStep.page.find('a.testcase-report').click(function(source) {
			PuppetryTestCaseService.getTestCaseReport(
					self._setId,
					wizardData.id,
					function(data, textStatus, jqXHR) {},
					EHexServiceUtil.onErrorHandler
			);
		});
		summaryStep.page.css('display', 'block');
		wizardData.steps.push(summaryStep);
		
		var onCompleteHandler = function(tab, navigation, index) {
			PuppetryWizardUI.showWait('Testfall ' + '„' + wizardData.name + '“' + ' wird abgeschlossen...');
			setTimeout(function() {
				PuppetryTestCaseService.completeTestCase(
						function(data, textStatus, jqXHR) {
							PuppetryWizardUI.hideWait();
							PuppetryWizardUI.showNext(index);
						}, 
						EHexServiceUtil.onErrorHandler,
						this
				);
			}, 500);
		};
		completeStep.onNext = onCompleteHandler;
		
		var onCloseHandler = function(tab, navigation, index) {
			PuppetryWizardUI.hideWizard();
		};		
		summaryStep.onNext = onCloseHandler;
		
		PuppetryWizardUI.startWizard(
				wizardData,
				wizardData.currentStepIndex,
				function(tab, navigation, index) {
					PuppetryWizardUI.showWait(tab.text() + ' wird ausgeführt...');
					setTimeout(function() {
						PuppetryTestCaseService.executeTestCaseStep(
								function(data, textStatus, jqXHR) {
									PuppetryWizardUI.hideWait();
									PuppetryWizardUI.showNext(index);
								}, 
								EHexServiceUtil.onErrorHandler,
								this
						);
					}, 500);					
				},
				function() {
					self.showUI();
				}, 
				function() {
					EHexDialogUI.showWait('Testfall ' + '„' + wizardData.name + '“' + ' wird abgebrochen...');
					PuppetryTestCaseService.cancelTestCase(
							function(data, textStatus, jqXHR) {
								EHexDialogUI.hideWait();
								self.showUI();
							}, 
							EHexServiceUtil.onErrorHandler,
							this
					);
				}
		);
	}
};

PuppetryLiveTestCaseUI.prototype.initUpload = function(stepPage, id, stepIndex) {
	var self = this;
	
	var dropzoneSelector = stepPage.find('.upload-data');
	var dropzoneElmt = dropzoneSelector[0];
	var clickableElmt = dropzoneSelector[0];
	
	if (!dropzoneElmt.dropzone) {				
		
		var previewSelector = stepPage.find('.upload-previews');
		var previewElmt = previewSelector[0];
		
		var previewTemplateSelector = previewSelector.find('.file-row-template');
		previewTemplateSelector.removeClass('file-row-template');
		var previewTemplate = previewTemplateSelector.parent().html();
		previewTemplateSelector.remove();
		
		var myDropzone = new Dropzone(dropzoneElmt, { // Make the whole body a dropzone
			url: '../testcaseset/testrun/' + id + '/step/' + stepIndex,
		    method: 'PUT',
			thumbnailWidth: 160,
			thumbnailHeight: 160,
			parallelUploads: 20,
			previewTemplate: previewTemplate,
			acceptedFiles: '.png,.jpg,.jpeg,.log,.txt',
			autoQueue: false, // Make sure the files aren't queued until manually added
			previewsContainer: previewElmt, // Define the container to display the previews
			clickable: clickableElmt // Define the element that should be used as click trigger to select files.
		});
		myDropzone.id = stepIndex;
		
		return true;
	}
	else {
		return false;
	}
};

PuppetryLiveTestCaseUI.prototype.getAuthMechName = function(authenticationMechanism) {
	var authMech = '';
	if (authenticationMechanism) {
		switch (authenticationMechanism) {						
		case 'NONE':
			authMech = 'ohne TLS';
			break;
		case 'WITHOUT_CLIENT_AUTH':
			authMech = 'TLS ohne Client Authentifizierung';
			break;
		case 'BASIC_AUTH':
			authMech = 'TLS mit Basis Authentifizierung';
			break;
		case 'CLIENT_AUTH':
			authMech = 'TLS mit Zertifikatsprüfung';
			break;
		default:
			authMech = '';
			break;
		}
	}
	
	return authMech;
};

PuppetryLiveTestCaseUI.prototype.getSDSStatusName = function(sdsStatus) {
	var status = '';
	if (sdsStatus) {
		switch (sdsStatus) {
		case 'SUPPORTED':
			status = 'Standard (PTV 1.6.0)';
			break;
		case 'SUPPORTED_MULTIPLE':
			status = 'Mehrere Versionen (inklusive PTV 1.6.0)';
			break;
		case 'WRONG_VSDS_URL':
			status = 'Nichtereichbarer VSD-Service';
			break;
		case 'NOT_SUPPORTED':
			status = 'Nicht unterstützt';
			break;
		case 'NOT_SUPPORTED_MULTIPLE':
			status = 'Mehrere nicht unterstützte Versionen';
			break;
		default:
			status = '';
			break;
		}
	}
	
	return status;
};

PuppetryLiveTestCaseUI.prototype.validateStep = function() {
	var self = this;
	var tab = $('#wizardDialog .modal-header .tabs li.active a');
	PuppetryWizardUI.showWait(tab.text() + ' wird erneut überprüft...');
	setTimeout(function() {
		PuppetryTestCaseService.validateTestCaseStep(
				function(data, textStatus, jqXHR) {
					PuppetryWizardUI.hideWait();
					
					var step = data.currentStep;
					if (step.validation && step.validationResultList) {
						var page = $('#wizardDialog .tab-content .tab-pane.active');
						self._validationResultRenderer(step, page);
					}
				},
				EHexServiceUtil.onErrorHandler,
				self
			);
	}, 500);
};

PuppetryLiveTestCaseUI.prototype.cancelTestCase = function() {
	var testCaseId = $(this._detailViewId).attr('testcase-id');
	var testCaseName = $(this._detailViewId).attr('label');
	
	EHexDialogUI.confirm('Sind Sie sicher, dass Sie Testfall '+ '„' + testCaseName + '“' +' abbrechen möchten?', function(result) {
		if (result) {
			PuppetryTestCaseService.cancelTestCase(
					testCaseId, 
					function(data, textStatus, jqXHR) {
						EHexAlertUI.showInfo('Testfall '+ '„' + testCaseName + '“' +' wurde abgebrochen.');
					}, 
					EHexServiceUtil.onErrorHandler,
					this
			);
		}
	});
};

PuppetryLiveTestCaseUI.prototype.getLogFile = function(source) {
	var self = this;

	var testCaseId;
	var testCaseName;
	
	if (source) {
		var testCaseElmt = $(source).closest('.live-testcase');
		testCaseId = testCaseElmt.attr('id');
		testCaseName = testCaseElmt.attr('label');
	} else {
		testCaseId = $(this._detailViewId).attr('testcase-id');
		testCaseName = $(this._detailViewId).attr('label');
	}

	if (testCaseId) {
		PuppetryTestCaseService.getTestCaseLog(
				self._setId,
				testCaseId, 
				function(data, textStatus, jqXHR) {}, 
				EHexServiceUtil.onErrorHandler,
				this
		);	
	}
};

PuppetryLiveTestCaseUI.prototype.getReportFile = function(source) {
	var self = this;

	var testCaseId;
	var testCaseName;
	
	if (source) {
		var testCaseElmt = $(source).closest('.live-testcase');
		testCaseId = testCaseElmt.attr('id');
		testCaseName = testCaseElmt.attr('label');
	} else {
		testCaseId = $(this._detailViewId).attr('testcase-id');
		testCaseName = $(this._detailViewId).attr('label');
	}

	if (testCaseId) {
		PuppetryTestCaseService.getTestCaseReport(
				self._setId,
				testCaseId, 
				function(data, textStatus, jqXHR) {}, 
				EHexServiceUtil.onErrorHandler,
				this
		);	
	}
};


PuppetryLiveTestCaseUI.prototype.validateGematikReportPrecondition = function(listViewId, downloadFunction) {
	if($(listViewId).find('.live-testcase.disabled').length > 0) {
		EHexAlertUI.showError('Der Testbericht kann nur erzeugt werden, wenn alle Testfälle durchgeführt wurden.');
	}
	else {
		PuppetryProfileService.getProfile(
				function(profile, textStatus, jqXHR ) {

					if ((!profile.psName) || profile.psName.length === 0 || //
							(!profile.psVersion) || profile.psVersion.length === 0 || //
							(!profile.testerName) || profile.testerName.length === 0) {
						
						EHexAlertUI.showError('Die Angaben für die Erstellung des Testberichts sind nicht vollständig.');
					}
					else {
						downloadFunction();
					}
				
				}, 
				EHexServiceUtil.onErrorHandler
		);
	}
	
};

PuppetryLiveTestCaseUI.prototype.getGematikZIP = function(source) {
	var self = this;
	self.validateGematikReportPrecondition(
			self._listViewId, 
			function () {
				PuppetryTestCaseService.getPSList(
						self._setId,
						function (psList) {
							if(psList.length > 1) {
								var msg = "Es sind unterschiedliche Angaben zum Primärsystem Name/Version (" + psList.toString() + ") in den Testfallergebnis PDFs vorhanden. \n\nSoll dennoch ein Testbericht erzeugt werden?";
								EHexDialogUI.confirm(msg, function () { PuppetryTestCaseService.downloadTestCasesReportZIP(self._setId); });
							}
							else {
								PuppetryTestCaseService.downloadTestCasesReportZIP(self._setId);
							}
						},
						EHexServiceUtil.onErrorHandler,
						self
				);
			}
	);
	
};

PuppetryLiveTestCaseUI.prototype.getZIP = function(source) {
	var self = this;	
	PuppetryTestCaseService.downloadTestCasesZIP(self._setId);	
};


