function PuppetrySmcbUI() {
	// Call the parent constructor
	AbstractDataListUI.call(this);
	
	this._header = '<span class="font-20">Karten &lt; </span><span class="font-50">Praxiskarten</span>';
	this._contentId = '.smcb-content';
	this._listViewId = '.smcb-list';
	this._entryId = '.smcb';
	this._entryTemplateId = '#smcb-template';
	this._sortBy = 'label';
	this._detailViewId = '.smcb-detail';
	this._menuItemId = '.admin-smcb';
	
	this._listEntryHandler = PuppetrySMCBService.getSMCBs;
	this._getEntryHandler = PuppetrySMCBService.getSMCB;
	this._newEntryHandler = PuppetrySMCBService.newSMCB;
	this._updateEntryHandler = PuppetrySMCBService.updateSMCB;
	this._addEntryHandler = PuppetrySMCBService.addSMCB;
	this._beforeRemoveEntryHandler = PuppetrySMCBService.getSMCBReferences;
	this._removeEntryHandler = PuppetrySMCBService.removeSMCB;
	this._validateEntryHandler = PuppetrySMCBService.validateSMCB;
	this._lockEntryHandler = PuppetrySMCBService.lockSMCB;
	this._unlockEntryHandler = PuppetrySMCBService.unlockSMCB;
	this._cloneEntryHandler = PuppetrySMCBService.cloneSMCB;
	
	this.pinStatus = new Array();
	this.cardTypes = new Array();	
};

//Create the prototype
PuppetrySmcbUI.prototype = Object.create(AbstractDataListUI.prototype);

//Set the "constructor" property 
PuppetrySmcbUI.prototype.constructor = PuppetrySmcbUI;

PuppetrySmcbUI.prototype.initUI = function() {
	AbstractDataListUI.prototype.initUI.call(this);
	
	var self = this;
	
	this.cardTypes.push({value: 'HBAX', label: 'HBA G2'});
	this.cardTypes.push({value: 'HBA_G21', label: 'HBA G2.1'});
	this.cardTypes.push({value: 'HBA_VK_QSIG', label: 'HBA-qSig'});
	this.cardTypes.push({value: 'HBA_VK_ZOD', label: 'ZOD_2.0'});
	this.cardTypes.push({value: 'SMCB', label: 'SMC-B G2'});
	this.cardTypes.push({value: 'SMCB_G21', label: 'SMC-B G2.1'});
	this.cardTypes.push({value: 'UNKNOWN', label: 'UNKNOWN'});
	
	PuppetrySMCBService.getPinStatus(function(data, textStatus, jqXHR) {
		self.initSelectData(data, self.pinStatus);
	}, EHexServiceUtil.onErrorHandler, this);
	
	PuppetrySMCBService.getSMCBs(this.onEntriesSuccess, EHexServiceUtil.onErrorHandler, this);
};

PuppetrySmcbUI.prototype.showUI = function(source, detail) {
	AbstractDataListUI.prototype.showUI.call(this, source, detail);
	
	$('.admin-mode > .header').html(this._header);
	
	var addItem = $('#add-item-toolbar-template').clone(true);
	addItem.removeAttr('id');
	$('.admin-mode > .toolbar-container').append(addItem);
	
	if ($('#wrapper').hasClass('live-mode')) {
		$('#wrapper').removeClass('live-mode').addClass('admin-mode');
		$('.live-mode').hide();
	}
	$('.admin-content').hide();
	$(this._contentId).show();	
};

PuppetrySmcbUI.prototype.toListView = function(model, viewElement) {
	AbstractDataListUI.prototype.toListView.call(this, model, viewElement);
	
	var self = this;
	
	viewElement.attr('id', model.id); 
	viewElement.attr('label', model.label);
	if (model.description) {
		viewElement.attr('description', model.description);	
	} else {
		viewElement.removeAttr('description');
	}
	viewElement.find('.smcb-name').text(model.label);
	viewElement.find('.smcb-description').text(model.description ? model.description : '<Keine Beschreibung vorhanden>');

	viewElement.find('.smcb-name').renamable({
		renaming: function(oldValue, newValue, success, error) {
			PuppetrySMCBService.renameSMCB(model.id, newValue, success, error, self);
		},
		success : function(data, textStatus, jqXHR) {
			self.toListView(data, $('.smcb-list').find('.smcb[id="' + data.id + '"]'));
			self.sortEntries();
			self.hideDetailUI();
		},
		error : EHexServiceUtil.onErrorHandler
	});
};

PuppetrySmcbUI.prototype.toDetailView = function(model, detailView) {
	AbstractDataListUI.prototype.toDetailView.call(this, model, detailView);
	
	this.initSelectBox(this.pinStatus, detailView.find('.initialpinstatus'), model.initialPinStatus);

	detailView.find('.smcb-name').val(model.label);
	detailView.find('.cardholdername').val(model.cardHolderName);
	detailView.find('.iccsn').val(model.iccsn);
	detailView.find('.description').val(model.description);
	detailView.find('.certexpirationdate').val(model.certExpirationDate != null ? $.datepicker.formatDate('dd.mm.yy', new Date(model.certExpirationDate)) : '');
	
	this.initSelectBox(this.cardTypes, detailView.find('.cardType'), model.cardType);
	
	detailView.find('input[type="checkbox"].smcb-administrated').prop('checked', model.administrated);
	if(model.cardType == "SMCB") {
		detailView.find('div.smcb-administrated').show();
	}
	else {
		detailView.find('div.smcb-administrated').hide();
	}
	
	if (model.id != null && model.id != '') {
		detailView.attr('smcb-id', model.id);
	} else {
		detailView.removeAttr('smcb-id');
	}
};

PuppetrySmcbUI.prototype.toggleCardType = function(source) {
	var detailView = $('.smcb-detail');

	var cardtype = detailView.find('.cardType').val();
	if(cardtype == "SMCB") {
		detailView.find('div.smcb-administrated').show();
	}
	else {
		detailView.find('div.smcb-administrated').hide();
	}
};


PuppetrySmcbUI.prototype.toModel = function(viewElement, model) {
	var validationResult = AbstractDataListUI.prototype.toModel.call(this, viewElement, model);

	model.id = viewElement.attr('smcb-id');
	model.iccsn =viewElement.find('.iccsn').val();
	model.label = viewElement.find('.smcb-name').val();
	model.description = viewElement.find('.description').val();
	model.cardHolderName = viewElement.find('.cardholdername').val();
	model.initialPinStatus = viewElement.find('.initialpinstatus').val();
	
	model.cardType = viewElement.find('.cardType').val();
	
	if(model.cardType == "SMCB") {
		model.administrated = viewElement.find('input[type="checkbox"].smcb-administrated').is(':checked');
	}
	else {
		model.administrated = true;
	}
	
	var certExpirationDate = viewElement.find('.certexpirationdate').val();
	if (certExpirationDate != null && certExpirationDate != '') {
		try {
			model.certExpirationDate = $.datepicker.parseDate('dd.mm.yy', certExpirationDate).getTime();
		} catch (e) {
			var warning = [{warningId : 'INVALID'}];
			validationResult.fieldWarnings.certExpirationDate = warning;
		}
	}
	
	if (model.label == null || model.label == '') {
		validationResult.errors.error = 'Das Feld "Label" ist verpflichtend!';
	}
	
	return validationResult;
};